"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BinaryService = void 0;
const common_1 = require("@nestjs/common");
const axios_1 = __importDefault(require("axios"));
const path_1 = __importDefault(require("path"));
const symbolItemType_1 = require("../../database/entities/types/symbolItemType");
const cancelationTask_1 = require("../../helpers/cancelationTask");
const delay_1 = require("../../helpers/delay");
const directoryProvider_1 = require("../helpers/directoryProvider");
const fileProvider_1 = require("../helpers/fileProvider");
const logger_service_1 = require("../logger/logger.service");
const metrics_service_1 = require("../metrics/metrics.service");
const symbol_item_service_1 = require("../symbol-item/symbol-item.service");
const symbol_server_logs_service_1 = require("../symbol-server-logs/symbol-server-logs.service");
const downloadTask_1 = require("./model/downloadTask");
const SymbolFile_1 = require("./model/SymbolFile");
const taskLogger_1 = require("./model/taskLogger");
let BinaryService = class BinaryService {
    constructor(_metrics, _logger, _symbolServerLogsService, _taskLogger, _fileProvider, _directoryProvider, _symbolItemService) {
        this._metrics = _metrics;
        this._logger = _logger;
        this._symbolServerLogsService = _symbolServerLogsService;
        this._taskLogger = _taskLogger;
        this._fileProvider = _fileProvider;
        this._directoryProvider = _directoryProvider;
        this._symbolItemService = _symbolItemService;
        this._downloadTasks = {};
        this._delayTasks = [];
        this._resolved = false;
    }
    get downloadTasks() {
        return this._downloadTasks;
    }
    async downloadStream(symbolName, debugId, symbolServers) {
        if (symbolServers.length === 0) {
            return undefined;
        }
        const cancellationToken = this.getCancellationToken();
        const listOfTasks = symbolServers.map((symbolServer) => {
            const possibleUrls = this.getSymbolUrl(symbolName, symbolServer);
            return possibleUrls.map((query, index) => {
                const numberOfConcurrentDownload = symbolServer.numberOfConcurrentDownload || 10;
                return new downloadTask_1.DownloadTask(symbolServer, symbolName, debugId, query, cancellationToken, numberOfConcurrentDownload <= index);
            });
        });
        const downloadTasks = [].concat.apply([], listOfTasks);
        const tasks = downloadTasks.map(async (downloadTask) => {
            try {
                const url = await downloadTask.authDownloadUrl();
                const response = await axios_1.default.get(url, downloadTask.getAxiosConfiguration());
                if (response.status !== 200) {
                    return undefined;
                }
                return response.data;
            }
            catch (err) {
                return undefined;
            }
        });
        const result = await Promise.all(tasks);
        return result.find((n) => n !== undefined);
    }
    async download(savePath, event, missingSymbol, symbolServers) {
        if (symbolServers.length === 0) {
            return [];
        }
        const [symbolName, debugId] = missingSymbol.split(',');
        this._logger.debug(`Downloading symbol: ${symbolName} debugId: ${debugId} `);
        const cancellationToken = this.getCancellationToken();
        const tasks = symbolServers.map((n) => this.downloadFromSymbolServer(n, symbolName, debugId, savePath, cancellationToken));
        this.CurrentSymbol = {
            event,
            missingSymbol,
        };
        const result = await this.filterResults(tasks);
        this.archiveDownloadInformation();
        return result;
    }
    archiveDownloadInformation() {
        this._downloadTasks = {};
        this.CurrentSymbol = undefined;
        this._resolved = false;
    }
    async filterResults(tasks) {
        const taskResults = await Promise.all(tasks);
        const result = [].concat(...taskResults);
        const success = result.filter((n) => n !== undefined);
        return success;
    }
    async downloadFromSymbolServer(symbolServer, symbolName, debugId, savePath, cancellationToken) {
        if (!this._downloadTasks[symbolServer.id]) {
            this._downloadTasks[symbolServer.id] = [];
        }
        else {
            await delay_1.Delay.wait();
            return await this.downloadFromSymbolServer(symbolServer, symbolName, debugId, savePath, cancellationToken);
        }
        const possibleUrls = this.getSymbolUrl(symbolName, symbolServer);
        const promises = possibleUrls.map((template, index) => {
            const numberOfConcurrentDownload = symbolServer.numberOfConcurrentDownload || 10;
            const task = new downloadTask_1.DownloadTask(symbolServer, symbolName, debugId, template, cancellationToken, numberOfConcurrentDownload <= index, savePath);
            ++this._metrics.data.numberOfDownloadTasks;
            this._downloadTasks[symbolServer.id].push(task);
            return numberOfConcurrentDownload > index ? this.downloadBinary(task) : undefined;
        });
        const symbolFiles = await Promise.all(promises);
        return await this.saveResults(symbolFiles, symbolName, debugId, symbolServer);
    }
    async saveResults(symbolFiles, symbolName, debugId, symbolServer) {
        const result = symbolFiles.filter((n) => n !== undefined);
        if (result.length === 0) {
            await this._symbolItemService.add({
                symbolName,
                debugId,
                symbolServerId: symbolServer.id,
                type: symbolItemType_1.SymbolItemType.SkipList,
            });
        }
        else {
            ++symbolServer.statistics.numberOfSuccessAtDownloadStage;
        }
        await symbolServer.statistics.save();
        await this._symbolServerLogsService.addCollection(symbolServer.id, symbolServer.logs);
        return result;
    }
    async downloadBinary(downloadTask) {
        if (this._resolved) {
            return undefined;
        }
        try {
            const url = await downloadTask.authDownloadUrl();
            this._taskLogger.info(`Downloading symbol: ${downloadTask.symbolName} debugId: ${downloadTask.debugId} from url ${url}`, downloadTask);
            if (!url) {
                ++downloadTask.symbolServer.statistics.numberOfFailuresAtDownloadStage;
                ++this._metrics.data.symbolsFailsOnDownloadStage;
                this._taskLogger.info(`Cannot generate authentication url for ${downloadTask.downloadUrl}. Please validate your symbol server credentials.`, downloadTask);
                return undefined;
            }
            const response = await axios_1.default.get(url, downloadTask.getAxiosConfiguration());
            if (response.headers && response.headers['content-type'] === 'text/html; charset=utf-8') {
                this._taskLogger.warn(`Symbol server has returned a response with text/html website for symbol symbol: ${downloadTask.symbolName} debugId: ${downloadTask.debugId} . Adding symbol to skip list.`, downloadTask);
                return undefined;
            }
            return await this.saveResult(downloadTask, response);
        }
        catch (err) {
            ++downloadTask.symbolServer.statistics.numberOfFailuresAtDownloadStage;
            ++this._metrics.data.symbolsFailsOnDownloadStage;
            if (axios_1.default.isCancel(err)) {
                ++this._metrics.data.canceledTasks;
                this._taskLogger.info(`${err.message} Skipping downloading symbol: ${downloadTask.symbolName} debugId: ${downloadTask.debugId} from ${downloadTask.downloadUrl}`, downloadTask);
                return undefined;
            }
            else if (err.isAxiosError) {
                this._taskLogger.warn(`Received error- symbol: ${downloadTask.symbolName} debugId: ${downloadTask.debugId} under url ${downloadTask.downloadUrl}. Message: ${err.message}`, downloadTask);
            }
            else {
                ++this._metrics.data.internalErrors;
                this._logger.error(err);
            }
        }
        ++downloadTask.numberOfRetry;
        if (downloadTask.hasExceededMaximumRetries()) {
            this._taskLogger.warn(`Retry limit hit- symbol: ${downloadTask.symbolName} debugId: ${downloadTask.debugId}. Symbol server: ${downloadTask.symbolServer.url} url: ${downloadTask.downloadUrl}`, downloadTask);
            const next = this.getNextTask(downloadTask);
            return next ? await this.downloadBinary(next) : undefined;
        }
        this._taskLogger.warn(`Waiting ${downloadTask.retryTimeout} before next download symbol: ${downloadTask.symbolName} debugId: ${downloadTask.debugId} `, downloadTask);
        await this.waitForNextRetry(downloadTask);
        return await this.downloadBinary(downloadTask);
    }
    async saveResult(downloadTask, response) {
        this._taskLogger.info(`Received status code 200 for symbol symbol: ${downloadTask.symbolName} debugId: ${downloadTask.debugId} from ${downloadTask.downloadUrl}`, downloadTask);
        const result = new SymbolFile_1.SymbolFile(downloadTask);
        await this._directoryProvider.createDirRecursively(path_1.default.dirname(result.symbolPath));
        this._logger.info(`Saving symbol in path: ${result.symbolPath} symbol: ${result.symbolName} debugId: ${result.debugId} `);
        await this._fileProvider.saveStream(result.symbolPath, response.data);
        await result.generateSymbolType();
        const totalBytes = await this._fileProvider.getSize(result.symbolPath);
        result.task.symbolServer.statistics.numberOfBytesDownloaded += totalBytes;
        ++this._metrics.data.symbolsDownloaded;
        this.cancelTasks();
        return result;
    }
    async waitForNextRetry(downloadTask) {
        ++this._metrics.data.symbolsRetriesOnDownloadStage;
        if (this._resolved) {
            return;
        }
        const cancelationToken = new cancelationTask_1.CancelationTask();
        const task = delay_1.Delay.wait(downloadTask.retryTimeout, cancelationToken);
        this._delayTasks.push(cancelationToken);
        await task;
        this._delayTasks = this._delayTasks.filter((n) => n.id !== cancelationToken.id);
    }
    cancelTasks() {
        this._resolved = true;
        this._delayTasks.forEach((n) => {
            n.cancel();
        });
        this._delayTasks = [];
    }
    getSymbolUrl(symbolName, symbolServer) {
        if (symbolServer.queryBuilder) {
            const templates = symbolServer.queryBuilder.split(';');
            for (const template of templates) {
                if (template.startsWith('<') && template.endsWith('>')) {
                }
            }
            return templates;
        }
        return [
            '{symbolName}/{debugId}/{symbolName}',
            '{symbolName}/{debugId}/{underscoreExtensionName}',
            symbolName.endsWith('.pdb')
                ? '{symbolName}/{debugId}/{baseName}.sym'
                : '{symbolName}/{debugId}/{symbolName}.sym',
        ];
    }
    getCancellationToken() {
        const cancellationTokenSource = axios_1.default.CancelToken.source();
        return cancellationTokenSource;
    }
    getNextTask(downloadTask) {
        const symbolServer = this._downloadTasks[downloadTask.symbolServer.id];
        if (!symbolServer) {
            return undefined;
        }
        const task = symbolServer.find((n) => n.waitList);
        if (task) {
            this._taskLogger.info('Loading new symbol from wait list', task);
            task.removeFromWaitList();
        }
        return task;
    }
};
BinaryService = __decorate([
    common_1.Injectable(),
    __metadata("design:paramtypes", [metrics_service_1.MetricsService,
        logger_service_1.LoggerService,
        symbol_server_logs_service_1.SymbolServerLogsService,
        taskLogger_1.TaskLogger,
        fileProvider_1.FileProvider,
        directoryProvider_1.DirectoryProvider,
        symbol_item_service_1.SymbolItemService])
], BinaryService);
exports.BinaryService = BinaryService;
//# sourceMappingURL=binary.service.js.map