"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CoronerService = void 0;
const common_1 = require("@nestjs/common");
const axios_1 = __importDefault(require("axios"));
const https_1 = __importDefault(require("https"));
const env_1 = require("../../env");
const delay_1 = require("../../helpers/delay");
const config_service_1 = require("../config/config.service");
const directoryProvider_1 = require("../helpers/directoryProvider");
const logger_service_1 = require("../logger/logger.service");
const metrics_service_1 = require("../metrics/metrics.service");
let CoronerService = class CoronerService {
    constructor(_metrics, _directoryProvider, _config, _logger) {
        var _a;
        this._metrics = _metrics;
        this._directoryProvider = _directoryProvider;
        this._config = _config;
        this._logger = _logger;
        this.connectionRetry = 3;
        this._httpsAgent = ((_a = env_1.service.configuration.descriptor) === null || _a === void 0 ? void 0 : _a.isOnPremise) ? new https_1.default.Agent({ rejectUnauthorized: false })
            : https_1.default.globalAgent;
    }
    async moveSymbols(converstionPath, model) {
        this._logger.info('Move files and invoke coronerd');
        if (model.symbols.length === 0) {
            return;
        }
        await this._directoryProvider.move(converstionPath, this._config.path.destination);
    }
    async pushResult(model) {
        this._logger.debug('Sending new data to coroner. Trying to reload');
        const { universe, project, object_id } = model;
        const requestData = {
            universe,
            project,
            objects: [object_id.toString(16)],
            action: 'reload',
            token: 'symbolServerLocalhostToken',
        };
        return this.sendDataToCoronerd(requestData, this.connectionRetry);
    }
    async getReportDetails(universe, project, objectId) {
        this._logger.debug(`Fetching report details. objectId ${objectId}`);
        try {
            const result = await this._config.identityManager.loginCoronerd(env_1.coronerdUrl);
            if (!result) {
                return undefined;
            }
            const response = await axios_1.default.get(`${env_1.coronerdUrl}/api/get`, {
                params: {
                    universe,
                    project,
                    object: objectId,
                    resource: 'json.gz',
                    token: result.token,
                },
                httpsAgent: this._httpsAgent,
            });
            if (response.status !== 200 && response.status !== ~500) {
                throw new Error(`Cannot download json dump in coronerd instance - ${env_1.coronerdUrl}`);
            }
            return response.data;
        }
        catch (err) {
            this._logger.warn(`Cannot download JSON report from coronerd. Params: universe=${universe} project=${project} objectId=${objectId} Reason: ${err.message}`);
            return undefined;
        }
    }
    async sendDataToCoronerd(requestData, retries) {
        var _a, _b;
        if (retries <= 0) {
            this._logger.warn(`Cannot reprocess object ${requestData.objects[0]}`);
            return false;
        }
        try {
            const result = await axios_1.default.post(`${env_1.coronerdUrl}/api/control`, requestData, {
                httpsAgent: this._httpsAgent,
            });
            if (result.status !== 200) {
                ++this._metrics.data.coronerdPushErrors;
                this._logger.warn(`Coronerd returns ${result.status} while reprocessing data.
            Data : ${JSON.stringify(requestData)}`);
                return this.sendDataToCoronerd(requestData, retries - 1);
            }
            else {
                ++this._metrics.data.coronerPushSuccess;
                this._logger.info(`Successfully send a data to coronerd. Object ID ${requestData.objects}`);
                return true;
            }
        }
        catch (err) {
            if (err.isAxiosError || axios_1.default.isCancel(err)) {
                ++this._metrics.data.coronerdPushErrors;
                this._logger.warn(`Cannot invoke coronerd process.
        Url: ${`${env_1.coronerdUrl}/api/control`}
        Error:  ${err}. ${((_a = err.response) === null || _a === void 0 ? void 0 : _a.data) ? JSON.stringify((_b = err.response) === null || _b === void 0 ? void 0 : _b.data) : ''}`);
                await delay_1.Delay.wait();
                return this.sendDataToCoronerd(requestData, retries - 1);
            }
            else {
                this._logger.error(err);
                return false;
            }
        }
    }
};
CoronerService = __decorate([
    common_1.Injectable(),
    __metadata("design:paramtypes", [metrics_service_1.MetricsService,
        directoryProvider_1.DirectoryProvider,
        config_service_1.ConfigService,
        logger_service_1.LoggerService])
], CoronerService);
exports.CoronerService = CoronerService;
//# sourceMappingURL=coroner.service.js.map