"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.LogRetentionService = void 0;
const common_1 = require("@nestjs/common");
const typeorm_1 = require("@nestjs/typeorm");
const typeorm_2 = require("typeorm");
const symbolServerLog_1 = require("../../database/entities/symbolServerLog");
const logger_service_1 = require("../logger/logger.service");
const config_service_1 = require("../config/config.service");
let LogRetentionService = class LogRetentionService {
    constructor(_symbolServerLogRepository, _logger, _config) {
        this._symbolServerLogRepository = _symbolServerLogRepository;
        this._logger = _logger;
        this._config = _config;
        this._nextInterval = 86400000;
    }
    async onApplicationBootstrap() {
        if (this._config.log.retention === undefined) {
            this._logger.info(`Skippling log retention. Symbold won't remove any logs`);
            return;
        }
        this._logger.info('Starting log retention');
        await this._symbolServerLogRepository
            .createQueryBuilder()
            .delete()
            .from(symbolServerLog_1.SymbolServerLog)
            .where(`creationDate < date('now', 'start of day', '-${this._config.log.retention} day')`)
            .execute();
        try {
            await this._symbolServerLogRepository.query('vacuum');
        }
        catch (err) {
            this._logger.info(`Cannot clear database data`);
        }
        this._logger.info(`Successfully removed old logs from database`);
        this._logger.info(`Starting new timer. Wait time: ${this._nextInterval} ms`);
        setTimeout(async () => {
            await this.onApplicationBootstrap();
        }, this._nextInterval);
    }
};
LogRetentionService = __decorate([
    common_1.Injectable(),
    __param(0, typeorm_1.InjectRepository(symbolServerLog_1.SymbolServerLog)),
    __metadata("design:paramtypes", [typeorm_2.Repository,
        logger_service_1.LoggerService,
        config_service_1.ConfigService])
], LogRetentionService);
exports.LogRetentionService = LogRetentionService;
//# sourceMappingURL=log-retention.service.js.map