"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.LoggerStartup = void 0;
const common_1 = require("@nestjs/common");
const backtrace_node_1 = require("backtrace-node");
const winston_1 = require("winston");
const env_1 = require("../../env");
const logger_service_1 = require("./logger.service");
const packageJson = require('./../../../package.json');
let LoggerStartup = class LoggerStartup {
    constructor(_loggerService) {
        this._loggerService = _loggerService;
    }
    onApplicationBootstrap() {
        this.loadBacktrace();
        this.loadWinston();
    }
    loadWinston() {
        if (env_1.env.log.level === 'trace') {
            env_1.env.log.level = 'info';
        }
        winston_1.configure({
            transports: [
                new winston_1.transports.Console({
                    silent: false,
                    level: env_1.env.log.level || 'info',
                    format: winston_1.format.combine(winston_1.format.colorize(), winston_1.format.simple()),
                }),
            ],
        });
    }
    loadBacktrace() {
        if (env_1.env.log.remoteLog === true || env_1.env.log.remoteLog === undefined) {
            const backtrace = backtrace_node_1.initialize({
                endpoint: env_1.env.log.backtraceUrl,
                handlePromises: true,
                disableGlobalHandler: false,
                attributes: {
                    'symbold.version': packageJson.version
                }
            });
            backtrace.on('before-data-send', (report, json) => {
                this._loggerService.warn(`Received exception in backtrace-node handler:
                Message ${report.getPayload().toString()}']} 
                Stack trace: ${JSON.stringify(json.threads)}`);
            });
        }
    }
};
LoggerStartup = __decorate([
    common_1.Injectable(),
    __metadata("design:paramtypes", [logger_service_1.LoggerService])
], LoggerStartup);
exports.LoggerStartup = LoggerStartup;
//# sourceMappingURL=logger.startup.js.map