"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MetricsService = void 0;
const common_1 = require("@nestjs/common");
const env_1 = require("../../env");
const logger_service_1 = require("../logger/logger.service");
const queue_service_1 = require("../queue/queue.service");
const symbol_server_logs_service_1 = require("../symbol-server-logs/symbol-server-logs.service");
const metricsStorage_1 = require("./model/metricsStorage");
let MetricsService = class MetricsService {
    constructor(_queueService, _logger, _symbolServerLogs) {
        this._queueService = _queueService;
        this._logger = _logger;
        this._symbolServerLogs = _symbolServerLogs;
        this.data = new metricsStorage_1.Metrics();
        if (env_1.service.metrics) {
            this._metricsStorage = env_1.service.metrics;
            this._metricsStorage.beforeSend = async () => {
                await this.update();
            };
            this._logger.info('Starting metrics service');
        }
    }
    async update() {
        if (!this._metricsStorage) {
            this._logger.verbose(`Metrics object is unvailable`);
            return;
        }
        this._logger.debug('Sending data to circonus');
        const eventStack = this._queueService.getEventStack();
        this.data.eventsInQueue = this._queueService.getQueueSize();
        this.data.numberOfLogs = await this._symbolServerLogs.countLogs();
        if (eventStack.length !== 0) {
            this.data.firstEventDate = eventStack[0].timestamp;
            this.data.firstEventId = eventStack[0].object_id;
            this.data.lastEventDate = eventStack[eventStack.length - 1].timestamp;
            this.data.lastEventId = eventStack[eventStack.length - 1].object_id;
        }
        else {
            this.data.firstEventDate = 0;
            this.data.firstEventId = 0;
            this.data.lastEventDate = 0;
            this.data.lastEventDate = 0;
        }
        this.data.eventsAllTime = this.data.validEvents + this.data.invalidEvents;
        const source = this.data;
        for (const key in source) {
            if (source.hasOwnProperty(key)) {
                const element = source[key];
                this.add(key, element);
                source[key] = 0;
            }
        }
    }
    add(name, value) {
        if (!this._metricsStorage) {
            return;
        }
        this._metricsStorage.addMetric(name, value);
    }
};
MetricsService = __decorate([
    common_1.Injectable(),
    __param(0, common_1.Inject(common_1.forwardRef(() => queue_service_1.QueueService))),
    __metadata("design:paramtypes", [queue_service_1.QueueService,
        logger_service_1.LoggerService,
        symbol_server_logs_service_1.SymbolServerLogsService])
], MetricsService);
exports.MetricsService = MetricsService;
//# sourceMappingURL=metrics.service.js.map