"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ErrorMiddleware = void 0;
const common_1 = require("@nestjs/common");
const backtrace_node_1 = require("backtrace-node");
const core_1 = require("@nestjs/core");
const metrics_service_1 = require("../metrics/metrics.service");
const env_1 = require("../../env");
let ErrorMiddleware = class ErrorMiddleware extends core_1.BaseExceptionFilter {
    constructor(_metricsService) {
        super();
        this._metricsService = _metricsService;
    }
    catch(exception, host) {
        var _a;
        const ctx = host.switchToHttp();
        const request = ctx.getRequest();
        const response = ctx.getResponse();
        ++this._metricsService.data.failedRequests;
        const status = exception instanceof common_1.HttpException ? exception.getStatus() : common_1.HttpStatus.INTERNAL_SERVER_ERROR;
        if (status !== 403) {
            env_1.service.identityManager.bypassProjectAccessCheck(response);
        }
        if (status >= 500) {
            ++this._metricsService.data.internalErrors;
            const client = backtrace_node_1.getBacktraceClient();
            if (client) {
                const report = client.createReport(exception);
                report.addAnnotation('request', request);
                client.sendReport(report);
            }
        }
        if (response.headersSent) {
            return;
        }
        if (typeof (exception === null || exception === void 0 ? void 0 : exception.message) === 'object' && Array.isArray(exception.message.message)) {
            const data = [];
            (_a = exception.message.message) === null || _a === void 0 ? void 0 : _a.forEach((n) => {
                if (n.constraints) {
                    data.push(n.constraints);
                }
                if (n.children) {
                    n.children.forEach((element) => {
                        data.push(element.constraints);
                    });
                }
            });
            const prettyMessages = [];
            data.forEach((item) => {
                if (!item) {
                    return;
                }
                Object.keys(item).forEach((key) => prettyMessages.push(item[key]));
            });
            exception.message.meta = prettyMessages;
        }
        super.catch(exception, host);
    }
};
ErrorMiddleware = __decorate([
    common_1.Catch(),
    __metadata("design:paramtypes", [metrics_service_1.MetricsService])
], ErrorMiddleware);
exports.ErrorMiddleware = ErrorMiddleware;
//# sourceMappingURL=errorMiddleware.js.map