"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MessageListenerService = void 0;
const common_1 = require("@nestjs/common");
const fs_1 = require("fs");
const path_1 = __importDefault(require("path"));
const config_service_1 = require("../config/config.service");
const directoryProvider_1 = require("../helpers/directoryProvider");
const fileProvider_1 = require("../helpers/fileProvider");
const logger_service_1 = require("../logger/logger.service");
const queue_service_1 = require("./queue.service");
let MessageListenerService = class MessageListenerService {
    constructor(_logger, _config, _fileProvider, _queueService, _directoryProvider) {
        this._logger = _logger;
        this._config = _config;
        this._fileProvider = _fileProvider;
        this._queueService = _queueService;
        this._directoryProvider = _directoryProvider;
        this._listenerEventName = 'rename';
    }
    async start() {
        const configPaths = this._config.path.eventPaths;
        const paths = [...new Set(configPaths)];
        await this.readEventsFromDirectory(this._config.path.eventStoragePath);
        for (const queuePath of paths) {
            this.listen(queuePath);
        }
        this._queueService.start();
    }
    async listen(queuePath) {
        const pathExists = await this._fileProvider.exists(queuePath);
        if (!pathExists) {
            this._logger.error(`Watch directory doesn't exists. Please make sure directory exists`);
            return;
        }
        this._logger.info(`Message listener starts watching directory: ${queuePath}`);
        await this.readEventsFromDirectory(queuePath);
        fs_1.watch(queuePath, async (eventType, eventPath) => {
            this.onCoronerMessage(eventType, path_1.default.join(queuePath, eventPath));
        });
    }
    async readEventsFromDirectory(eventDirectory) {
        const files = await this._directoryProvider.listAllFilesInDir(eventDirectory);
        for (const file of files) {
            this.onCoronerMessage(this._listenerEventName, path_1.default.join(eventDirectory, file));
        }
    }
    onCoronerMessage(eventType, eventPath) {
        if (eventType !== this._listenerEventName) {
            return;
        }
        this._queueService.add(eventPath);
    }
};
MessageListenerService = __decorate([
    common_1.Injectable(),
    __metadata("design:paramtypes", [logger_service_1.LoggerService,
        config_service_1.ConfigService,
        fileProvider_1.FileProvider,
        queue_service_1.QueueService,
        directoryProvider_1.DirectoryProvider])
], MessageListenerService);
exports.MessageListenerService = MessageListenerService;
//# sourceMappingURL=message-listener.service.js.map