"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CoronerdEvent = void 0;
const fs_1 = __importDefault(require("fs"));
const fs_extra_1 = require("fs-extra");
const path_1 = __importDefault(require("path"));
const util_1 = __importDefault(require("util"));
class CoronerdEvent {
    constructor(eventPath) {
        this.eventPath = eventPath;
        this._eventLoaded = false;
        this._loaded = false;
    }
    async eventExists() {
        if (this._eventLoaded === true) {
            return true;
        }
        return await util_1.default.promisify(fs_1.default.exists)(this.eventPath);
    }
    async loadEvent() {
        if (this._loaded) {
            return true;
        }
        if (!this._eventLoaded) {
            await this.readEvent();
            if (!this._eventLoaded) {
                return false;
            }
        }
        if (this.validateEvent()) {
            throw new Error(`Coronerd generated message with empty missing_symbols property. Object won't be available in symbold`);
        }
        this.groupSymbols();
        this.extendMissingSymbolsData();
        this._loaded = true;
        this.numberOfConvertedSymbols = 0;
        return this._loaded;
    }
    groupSymbols() {
        this.missingSymbolsData = {};
        for (const missingSymbol of this.missing_symbols) {
            const [fullFileName] = missingSymbol.split(',');
            const extension = path_1.default.extname(fullFileName);
            const fileName = path_1.default.basename(fullFileName, extension);
            if (this.missingSymbolsData[fileName]) {
                this.missingSymbolsData[fileName].add(missingSymbol);
            }
            else {
                this.missingSymbolsData[fileName] = new Set([missingSymbol]);
            }
        }
    }
    validateEvent() {
        return !this.missing_symbols || this.missing_symbols.length === 0;
    }
    async readEvent() {
        const file = await fs_extra_1.readFile(this.eventPath, 'utf-8');
        if (!file) {
            return;
        }
        const plainObject = JSON.parse(file);
        plainObject._eventLoaded = true;
        Object.assign(this, plainObject);
    }
    extendMissingSymbolsData() {
        for (const iterator in this.missingSymbolsData) {
            const data = this.missingSymbolsData[iterator];
            const entriesToCheck = data.size;
            let index = 0;
            for (const missingSymbol of data) {
                const [oryginalSymbolName, debugId] = missingSymbol.split(',');
                const extension = path_1.default.extname(oryginalSymbolName);
                const oryginalbaseSymbolName = path_1.default.basename(oryginalSymbolName, extension);
                if (extension === '.pdb') {
                    const exeName = `${oryginalbaseSymbolName}.exe,${debugId}`;
                    const dllName = `${oryginalbaseSymbolName}.dll,${debugId}`;
                    const containsMissingSymbols = data.has(exeName) || data.has(dllName);
                    if (!containsMissingSymbols) {
                        this.extendEvent(exeName, data);
                        this.extendEvent(dllName, data);
                    }
                }
                else if (extension === '.exe' || extension === '.dll') {
                    const pdbName = `${oryginalbaseSymbolName}.pdb,${debugId}`;
                    if (!data.has(pdbName)) {
                        this.extendEvent(pdbName, data);
                    }
                }
                index++;
                if (index >= entriesToCheck) {
                    break;
                }
            }
        }
    }
    extendEvent(name, symbolContainer) {
        this.missing_symbols.push(name);
        this.missing_symbol_count++;
        symbolContainer.add(name);
    }
}
exports.CoronerdEvent = CoronerdEvent;
//# sourceMappingURL=coronerEvent.js.map