"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.QueueController = void 0;
const common_1 = require("@nestjs/common");
const authGuard_1 = require("../../guards/authGuard");
const superUserGuard_1 = require("../../guards/superUserGuard");
const config_service_1 = require("../config/config.service");
const universe_service_1 = require("../universe/universe.service");
const createCoronerEvent_1 = require("./models/createCoronerEvent");
const queue_service_1 = require("./queue.service");
let QueueController = class QueueController {
    constructor(_universeService, _queueService, _configService) {
        this._universeService = _universeService;
        this._queueService = _queueService;
        this._configService = _configService;
    }
    getEventStack(res) {
        this._configService.identityManager.bypassProjectAccessCheck(res);
        res.send(this._queueService.getEventStack());
    }
    async add(res, model) {
        this._configService.identityManager.bypassProjectAccessCheck(res);
        model.validateMissingSymbols();
        const validUniverse = await this._universeService.fetchOrTryAdd(model.universeName, model.projectName);
        if (!validUniverse) {
            throw new common_1.BadRequestException('Invalid universe or project');
        }
        model.universe = validUniverse;
        const result = await this._queueService.createEvent(model);
        res.send(result);
    }
    countEventStack(res) {
        this._configService.identityManager.bypassProjectAccessCheck(res);
        res.send({
            queueSize: this._queueService.getQueueSize(),
        });
    }
    getMissingSymbols(res) {
        this._configService.identityManager.bypassProjectAccessCheck(res);
        res.send(this._queueService
            .getEventStack()
            .filter((n) => n && n.missing_symbols)
            .map((n) => {
            return {
                processing: n.processing || false,
                object_id: n.object_id,
                symbols: n.missing_symbols,
            };
        }));
    }
};
__decorate([
    common_1.UseGuards(superUserGuard_1.SuperUserGuard),
    common_1.UseGuards(authGuard_1.AuthGuard),
    common_1.Get('/events'),
    __param(0, common_1.Res()),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", void 0)
], QueueController.prototype, "getEventStack", null);
__decorate([
    common_1.UseGuards(superUserGuard_1.SuperUserGuard),
    common_1.UseGuards(authGuard_1.AuthGuard),
    common_1.Post('/add'),
    __param(0, common_1.Res()),
    __param(1, common_1.Body(new common_1.ValidationPipe({ transform: true }))),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, createCoronerEvent_1.CreateCoronerEvent]),
    __metadata("design:returntype", Promise)
], QueueController.prototype, "add", null);
__decorate([
    common_1.Get('/events/count'),
    __param(0, common_1.Res()),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", void 0)
], QueueController.prototype, "countEventStack", null);
__decorate([
    common_1.UseGuards(superUserGuard_1.SuperUserGuard),
    common_1.UseGuards(authGuard_1.AuthGuard),
    common_1.Get('/missingSymbols'),
    __param(0, common_1.Res()),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", void 0)
], QueueController.prototype, "getMissingSymbols", null);
QueueController = __decorate([
    common_1.Controller('queue'),
    __metadata("design:paramtypes", [universe_service_1.UniverseService,
        queue_service_1.QueueService,
        config_service_1.ConfigService])
], QueueController);
exports.QueueController = QueueController;
//# sourceMappingURL=queue.controller.js.map