"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.QueueService = void 0;
const common_1 = require("@nestjs/common");
const class_transformer_1 = require("class-transformer");
const path = __importStar(require("path"));
const delay_1 = require("../../helpers/delay");
const guidHelper_1 = require("../../helpers/guidHelper");
const config_service_1 = require("../config/config.service");
const directoryProvider_1 = require("../helpers/directoryProvider");
const fileProvider_1 = require("../helpers/fileProvider");
const logger_service_1 = require("../logger/logger.service");
const metrics_service_1 = require("../metrics/metrics.service");
const symbols_service_1 = require("../symbols/symbols.service");
const universe_service_1 = require("../universe/universe.service");
const coronerEvent_1 = require("./models/coronerEvent");
let QueueService = class QueueService {
    constructor(_directoryProvider, _config, _metrics, _logger, _fileProvider, _symbolService, _universeService) {
        this._directoryProvider = _directoryProvider;
        this._config = _config;
        this._metrics = _metrics;
        this._logger = _logger;
        this._fileProvider = _fileProvider;
        this._symbolService = _symbolService;
        this._universeService = _universeService;
        this._messageCache = new Map();
        this._eventStack = [];
        this._newEventStack = [];
        this._reprocessing = false;
    }
    start() {
        setInterval(() => {
            this._messageCache.clear();
        }, 1800000);
    }
    async createEvent(newEvent) {
        const eventToTransform = {
            _eventLoaded: true,
            missing_symbols: newEvent.missingSymbols,
            project: newEvent.projectName,
            universe: newEvent.universeName,
            object_id: newEvent.objectId,
        };
        const event = class_transformer_1.plainToClass(coronerEvent_1.CoronerdEvent, eventToTransform);
        event.queueAddDate = new Date();
        this._eventStack.unshift(event);
        this.reprocess();
    }
    getEventStack() {
        if (!this._current) {
            return [];
        }
        return [this._current, ...this._eventStack];
    }
    getQueueSize() {
        return this._eventStack.length + this._newEventStack.length + (this._current ? 1 : 0);
    }
    add(eventPath) {
        this._newEventStack.push(eventPath);
        this.reprocess();
    }
    async getNextEvent() {
        if (this._eventStack.length !== 0) {
            return this._eventStack.shift();
        }
        if (this._newEventStack.length === 0) {
            return undefined;
        }
        const minEventPayloadSize = 300;
        const numberOfEventsToLoad = Math.min(minEventPayloadSize, this._newEventStack.length);
        for (let index = 0; index <= numberOfEventsToLoad; index++) {
            const pathToNewEvent = this._newEventStack.pop();
            if (!pathToNewEvent) {
                break;
            }
            let eventPath = '';
            if (pathToNewEvent.indexOf(this._config.path.eventStoragePath) === -1) {
                if (!(await this._fileProvider.exists(pathToNewEvent))) {
                    continue;
                }
                eventPath = path.join(this._config.path.eventStoragePath, path.basename(pathToNewEvent));
                if (this._messageCache.has(eventPath)) {
                    this._logger.warn(`Detected duplicated event. ${eventPath}. Symbold already processed this event - time: ${this._messageCache.get(eventPath)}`);
                    await this._fileProvider.delete(pathToNewEvent);
                    continue;
                }
                if (await this._fileProvider.exists(eventPath)) {
                    this._logger.warn(`Detected redundant event. File already exist in the cur directory. Event path: ${path.basename(pathToNewEvent)}`);
                    await this._fileProvider.delete(pathToNewEvent);
                    continue;
                }
                await this._fileProvider.move(pathToNewEvent, eventPath);
            }
            else {
                eventPath = pathToNewEvent;
            }
            this._messageCache.set(eventPath, Date.now());
            const event = new coronerEvent_1.CoronerdEvent(eventPath);
            event.queueAddDate = new Date();
            if (await event.loadEvent()) {
                this._eventStack.push(event);
            }
            else if (await this._fileProvider.exists(eventPath)) {
                await this._fileProvider.delete(eventPath);
            }
        }
        if (this._eventStack.length === 0 && this._newEventStack.length > 0) {
            return await this.getNextEvent();
        }
        return this._eventStack.length !== 0 ? this._eventStack.shift() : undefined;
    }
    isOnDownloadStage(symbolName, debugId) {
        var _a, _b;
        const event = (_b = (_a = this._current) === null || _a === void 0 ? void 0 : _a.missing_symbols) === null || _b === void 0 ? void 0 : _b.some((n) => n && n === `${symbolName},${debugId}`);
        return event === true;
    }
    getSymbolStatus(symbolName, debugId) {
        var _a;
        const missingSymbolString = `${symbolName},${debugId}`;
        const result = {
            numberOfSymbolsBefore: 0,
            numbersOfEventsBefore: 0,
        };
        let found = false;
        for (let index = 0; index < this._eventStack.length; index++) {
            const event = this._eventStack[index];
            const symbolIndex = (_a = event.missing_symbols) === null || _a === void 0 ? void 0 : _a.findIndex((n) => n === missingSymbolString);
            if (symbolIndex !== -1) {
                found = true;
                break;
            }
            result.numberOfSymbolsBefore += event.missing_symbol_count;
            result.numbersOfEventsBefore += 1;
        }
        return !found ? undefined : result;
    }
    async handleEvent(event, downloadPath) {
        if (this._config.path.tryCompressed) {
            await this._symbolService.decompress(event);
        }
        await this._symbolService.get(event, downloadPath);
    }
    async updateCurrentEvent() {
        if (this._reprocessing) {
            return;
        }
        this._reprocessing = true;
        try {
            this._current = await this.getNextEvent();
        }
        finally {
            this._reprocessing = false;
        }
    }
    async reprocess() {
        if (this._current) {
            return;
        }
        await this.updateCurrentEvent();
        if (!this._current) {
            return;
        }
        const startHrTime = process.hrtime();
        const event = this._current;
        const downloadPath = path.join(this._config.path.downloadPath, guidHelper_1.Guid.NewGuid());
        event.processing = true;
        try {
            if ((await event.eventExists()) && (await event.loadEvent())) {
                event.universeEntity = await this.tryAddUniverse(event);
                this._logger.debug(`Start reprocessing symbols for object id ${event.object_id}`);
                await Promise.race([
                    this.handleEvent(event, downloadPath),
                    delay_1.Delay.wait(this._symbolService.DefaultTimeout),
                ]);
                ++this._metrics.data.validEvents;
            }
            else {
                this._logger.info(`Event from symbold queue doesn't exists on hard drive. Skipping report`);
            }
        }
        catch (err) {
            ++this._metrics.data.invalidEvents;
            this._logger.error(err, new Error().stack);
            this._logger.warn(`Received exception while reprocessing event with id ${event.object_id}. msg: ${err.msg}`);
        }
        finally {
            await this._directoryProvider.remove(downloadPath);
            this._logger.debug(`Reprocessing ends for event with object id ${event.object_id}`);
            const elapsedHrTime = process.hrtime(startHrTime);
            const elapsedTimeInMs = elapsedHrTime[0] * 1000 + elapsedHrTime[1] / 1e6;
            this._metrics.add('avgReprocessTime', elapsedTimeInMs);
            await this.next(event);
        }
    }
    async next(processingEvent) {
        this._current = undefined;
        await this._fileProvider.delete(processingEvent.eventPath);
        await this.reprocess();
    }
    async tryAddUniverse(event) {
        const universe = await this._universeService.fetchOrTryAdd(event.universe, event.project);
        if (!universe) {
            throw new Error(`Cannot add/find universe with name ${event.universe}`);
        }
        return universe;
    }
};
QueueService = __decorate([
    common_1.Injectable(),
    __param(2, common_1.Inject(common_1.forwardRef(() => metrics_service_1.MetricsService))),
    __param(5, common_1.Inject(common_1.forwardRef(() => symbols_service_1.SymbolService))),
    __metadata("design:paramtypes", [directoryProvider_1.DirectoryProvider,
        config_service_1.ConfigService,
        metrics_service_1.MetricsService,
        logger_service_1.LoggerService,
        fileProvider_1.FileProvider,
        symbols_service_1.SymbolService,
        universe_service_1.UniverseService])
], QueueService);
exports.QueueService = QueueService;
//# sourceMappingURL=queue.service.js.map