"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ReprocessService = void 0;
const common_1 = require("@nestjs/common");
const class_transformer_1 = require("class-transformer");
const path_1 = __importDefault(require("path"));
const delay_1 = require("../../helpers/delay");
const guidHelper_1 = require("../../helpers/guidHelper");
const config_service_1 = require("../config/config.service");
const coroner_service_1 = require("../coroner/coroner.service");
const logger_service_1 = require("../logger/logger.service");
const coronerEvent_1 = require("../queue/models/coronerEvent");
const symbols_service_1 = require("../symbols/symbols.service");
const universe_service_1 = require("../universe/universe.service");
let ReprocessService = class ReprocessService {
    constructor(_logger, _config, _universeService, _coronerdService, _symbolService) {
        this._logger = _logger;
        this._config = _config;
        this._universeService = _universeService;
        this._coronerdService = _coronerdService;
        this._symbolService = _symbolService;
    }
    async reprocess(universeName, projectName, objectId) {
        var _a;
        const universe = await this._universeService.fetchOrTryAdd(universeName, projectName);
        if (!universe) {
            throw new common_1.BadRequestException(`Universe doesn't exist`);
        }
        const backtraceReport = await this._coronerdService.getReportDetails(universeName, projectName, objectId);
        if (!backtraceReport) {
            this._logger.warn(`Cannot reprocess report. Cannot fetch report details for object id: ${objectId}`);
            throw new common_1.UnprocessableEntityException('Cannot fetch backtrace report details');
        }
        const missingSymbols = (_a = backtraceReport.annotations) === null || _a === void 0 ? void 0 : _a['Missing Symbols'];
        if (!missingSymbols) {
            this._logger.info(`Report doesn't have information about missing symbols. Ignoring...`);
            return { symbolsDownloaded: 0, symbolsConverted: 0, symbolsRequested: 0 };
        }
        const eventToTransform = {
            _eventLoaded: true,
            missing_symbols: [],
            project: projectName,
            universe: universeName,
            object_id: objectId,
        };
        for (const missingSymbol of missingSymbols) {
            eventToTransform.missing_symbols.push(`${missingSymbol.debug_file},${missingSymbol.debug_identifier}`);
            eventToTransform.missing_symbols.push(`${missingSymbol.debug_file},${missingSymbol.code_identifier}`);
            if (missingSymbol.path !== missingSymbol.debug_file) {
                eventToTransform.missing_symbols.push(`${missingSymbol.path},${missingSymbol.debug_identifier}`);
                eventToTransform.missing_symbols.push(`${missingSymbol.path},${missingSymbol.code_identifier}`);
            }
        }
        const event = class_transformer_1.plainToClass(coronerEvent_1.CoronerdEvent, eventToTransform);
        await event.loadEvent();
        event.universeEntity = universe;
        const downloadPath = path_1.default.join(this._config.path.downloadPath, guidHelper_1.Guid.NewGuid());
        this._logger.info(`Processing event ${event.object_id} - download path ${downloadPath}`);
        await Promise.race([
            this._symbolService.get(event, downloadPath, true),
            delay_1.Delay.wait(this._symbolService.DefaultTimeout),
        ]);
        return {
            symbolsRequested: event.missing_symbols.length,
            symbolsDownloaded: event.symbols.length,
            symbolsConverted: event.numberOfConvertedSymbols,
        };
    }
};
ReprocessService = __decorate([
    common_1.Injectable(),
    __metadata("design:paramtypes", [logger_service_1.LoggerService,
        config_service_1.ConfigService,
        universe_service_1.UniverseService,
        coroner_service_1.CoronerService,
        symbols_service_1.SymbolService])
], ReprocessService);
exports.ReprocessService = ReprocessService;
//# sourceMappingURL=reprocess.service.js.map