"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SkipListController = void 0;
const common_1 = require("@nestjs/common");
const symbol_item_service_1 = require("../symbol-item/symbol-item.service");
const symbolItemType_1 = require("../../database/entities/types/symbolItemType");
const parseOptionalInt_1 = require("../../pipes/parseOptionalInt");
const authGuard_1 = require("../../guards/authGuard");
const logger_service_1 = require("../logger/logger.service");
const config_service_1 = require("../config/config.service");
let SkipListController = class SkipListController {
    constructor(_logger, _symbolItemService, _configService) {
        this._logger = _logger;
        this._symbolItemService = _symbolItemService;
        this._configService = _configService;
        this._symbolItemType = symbolItemType_1.SymbolItemType.SkipList;
    }
    async get(req, res, symbolServerId, page, take) {
        if (!req.coronerAuth || !req.coronerAuth.cfg) {
            this._configService.identityManager.bypassProjectAccessCheck(res);
            return res.send();
        }
        this._logger.info(`User ${req.coronerAuth.cfg.username} fetch symbol server ${symbolServerId} skiplist`);
        const results = await this._symbolItemService.getBySymbolServerIdWithProjectValidation(this._configService, req, res, symbolServerId, this._symbolItemType, page, take);
        res.send(results);
    }
    async getByText(req, res, symbolServerId, text, page, take) {
        if (!req.coronerAuth || !req.coronerAuth.cfg) {
            this._configService.identityManager.bypassProjectAccessCheck(res);
            return res.send();
        }
        this._logger.info(`User ${req.coronerAuth.cfg.username} fetch symbol server ${symbolServerId} skiplist`);
        if (!text) {
            this._configService.identityManager.bypassProjectAccessCheck(res);
            return res.send({});
        }
        const results = await this._symbolItemService.getByTextWithProjectValidation(this._configService, req, res, symbolServerId, text, this._symbolItemType, page, take);
        res.send(results);
    }
    async delete(req, res, skipSymbolId) {
        if (!req.coronerAuth || !req.coronerAuth.cfg) {
            this._configService.identityManager.bypassProjectAccessCheck(res);
            return res.send();
        }
        this._logger.info(`User ${req.coronerAuth.cfg.username} trying to remove skiplist item ${skipSymbolId}`);
        await this._symbolItemService.removeWithProjectValidation(this._configService, req, res, skipSymbolId, this._symbolItemType);
        res.send({
            statusCode: 200,
            message: 'deleted',
            err: undefined,
        });
    }
    async deleteByText(req, res, text, skipSymbolId) {
        if (!req.coronerAuth || !req.coronerAuth.cfg) {
            this._configService.identityManager.bypassProjectAccessCheck(res);
            return res.send();
        }
        this._logger.info(`User ${req.coronerAuth.cfg.username} trying to remove skiplist item ${skipSymbolId}`);
        if (!text) {
            this._configService.identityManager.bypassProjectAccessCheck(res);
            throw new common_1.BadRequestException('Text is empty');
        }
        await this._symbolItemService.deleteByTextWithProjectValidation(this._configService, req, res, skipSymbolId, text, this._symbolItemType);
        res.send({
            statusCode: 200,
            message: 'deleted',
            err: undefined,
        });
    }
    async deleteAll(req, res, symbolServerId) {
        if (!req.coronerAuth || !req.coronerAuth.cfg) {
            this._configService.identityManager.bypassProjectAccessCheck(res);
            return res.send();
        }
        this._logger.info(`User ${req.coronerAuth.cfg.username} trying to clean symbol server ${symbolServerId} skiplist`);
        await this._symbolItemService.removeAllWithProjectValidation(this._configService, req, res, symbolServerId, this._symbolItemType);
        res.send({
            statusCode: 200,
            message: 'deleted',
            err: undefined,
        });
    }
};
__decorate([
    common_1.Get(':symbolServerId'),
    __param(0, common_1.Req()),
    __param(1, common_1.Res()),
    __param(2, common_1.Param('symbolServerId', new common_1.ParseIntPipe())),
    __param(3, common_1.Query('page', new parseOptionalInt_1.ParseOptionalIntPipe())),
    __param(4, common_1.Query('take', new parseOptionalInt_1.ParseOptionalIntPipe())),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, Object, Number, Object, Object]),
    __metadata("design:returntype", Promise)
], SkipListController.prototype, "get", null);
__decorate([
    common_1.Get(':symbolServerId/text/:text'),
    __param(0, common_1.Req()),
    __param(1, common_1.Res()),
    __param(2, common_1.Param('symbolServerId', new common_1.ParseIntPipe())),
    __param(3, common_1.Param('text')),
    __param(4, common_1.Query('page', new parseOptionalInt_1.ParseOptionalIntPipe())),
    __param(5, common_1.Query('take', new parseOptionalInt_1.ParseOptionalIntPipe())),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, Object, Number, String, Object, Object]),
    __metadata("design:returntype", Promise)
], SkipListController.prototype, "getByText", null);
__decorate([
    common_1.Delete(':skipSymbolId'),
    __param(0, common_1.Req()),
    __param(1, common_1.Res()),
    __param(2, common_1.Param('skipSymbolId', new common_1.ParseIntPipe())),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, Object, Number]),
    __metadata("design:returntype", Promise)
], SkipListController.prototype, "delete", null);
__decorate([
    common_1.Delete(':skipSymbolId/text/:text'),
    __param(0, common_1.Req()),
    __param(1, common_1.Res()),
    __param(2, common_1.Param('text')),
    __param(3, common_1.Param('skipSymbolId', new common_1.ParseIntPipe())),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, Object, String, Number]),
    __metadata("design:returntype", Promise)
], SkipListController.prototype, "deleteByText", null);
__decorate([
    common_1.Delete(':symbolServerId/all'),
    __param(0, common_1.Req()),
    __param(1, common_1.Res()),
    __param(2, common_1.Param('symbolServerId', new common_1.ParseIntPipe())),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, Object, Number]),
    __metadata("design:returntype", Promise)
], SkipListController.prototype, "deleteAll", null);
SkipListController = __decorate([
    common_1.Controller('skiplist'),
    common_1.UseGuards(authGuard_1.AuthGuard),
    __metadata("design:paramtypes", [logger_service_1.LoggerService,
        symbol_item_service_1.SymbolItemService,
        config_service_1.ConfigService])
], SkipListController);
exports.SkipListController = SkipListController;
//# sourceMappingURL=skip-list.controller.js.map