"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.StatusController = void 0;
const common_1 = require("@nestjs/common");
const authGuard_1 = require("../../guards/authGuard");
const authHelper_1 = require("../../helpers/authHelper");
const config_service_1 = require("../config/config.service");
const logger_service_1 = require("../logger/logger.service");
const universe_service_1 = require("../universe/universe.service");
const status_service_1 = require("./status.service");
let StatusController = class StatusController {
    constructor(_logger, _statusService, _universeService, _configService) {
        this._logger = _logger;
        this._statusService = _statusService;
        this._universeService = _universeService;
        this._configService = _configService;
    }
    async getSymbolDeatils(req, res, universeName, projectName, symbolName, debugId) {
        if (!this._configService.identityManager.checkProjectAccess(req, res, [projectName])) {
            return res.send();
        }
        if (!req.coronerAuth || !req.coronerAuth.cfg) {
            throw new common_1.BadRequestException('Missing auth data');
        }
        if (!authHelper_1.AuthHelper.checkUserAccess(req.coronerAuth, universeName)) {
            this._logger.warn(`User without access to universe tried to to fetch symbol status for universe: ${universeName}  ${projectName} `);
            throw new common_1.UnauthorizedException();
        }
        const universe = await this._universeService.fetchOrTryAdd(universeName, projectName);
        if (!universe) {
            throw new common_1.UnauthorizedException();
        }
        this._logger.info(`User ${req.coronerAuth.cfg.username} fetch symbol details`);
        const results = await this._statusService.getSymbolInformation(universeName, projectName, symbolName, debugId);
        res.send(results);
    }
    async get(req, res, universeName) {
        this._configService.identityManager.bypassProjectAccessCheck(res);
        if (!req.coronerAuth || !req.coronerAuth.cfg) {
            throw new common_1.BadRequestException('Missing auth data');
        }
        if (!authHelper_1.AuthHelper.checkUserAccess(req.coronerAuth, universeName)) {
            this._logger.warn(`User without access to universe tried to fetch symbol status for universe: ${universeName}`);
            throw new common_1.UnauthorizedException();
        }
        const universe = await this._universeService.fetchOrTryAdd(universeName);
        if (!universe) {
            throw new common_1.UnauthorizedException();
        }
        this._logger.info(`User ${req.coronerAuth.cfg.username} fetch universe ${universeName} status`);
        const results = this._statusService.getStatus(universeName);
        res.send(results);
    }
    async getByProjectName(req, res, universeName, projectName) {
        if (!this._configService.identityManager.checkProjectAccess(req, res, [projectName])) {
            return res.send();
        }
        if (!req.coronerAuth || !req.coronerAuth.cfg) {
            throw new common_1.BadRequestException('Missing auth data');
        }
        if (!authHelper_1.AuthHelper.checkUserAccess(req.coronerAuth, universeName)) {
            this._logger.warn(`User without access to universe tried to to fetch symbol status for universe: ${universeName}  ${projectName} `);
            throw new common_1.UnauthorizedException();
        }
        const universe = await this._universeService.fetchOrTryAdd(universeName, projectName);
        if (!universe) {
            throw new common_1.UnauthorizedException();
        }
        this._logger.info(`User ${req.coronerAuth.cfg.username} fetch project ${projectName} status`);
        const results = this._statusService.getStatusForProject(universeName, projectName);
        res.send(results);
    }
};
__decorate([
    common_1.Get('universe/:universeName/project/:projectName/:symbolName/:debugId'),
    __param(0, common_1.Req()),
    __param(1, common_1.Res()),
    __param(2, common_1.Param('universeName')),
    __param(3, common_1.Param('projectName')),
    __param(4, common_1.Param('symbolName')),
    __param(5, common_1.Param('debugId')),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, Object, String, String, String, String]),
    __metadata("design:returntype", Promise)
], StatusController.prototype, "getSymbolDeatils", null);
__decorate([
    common_1.Get('universe/:universeName'),
    __param(0, common_1.Req()),
    __param(1, common_1.Res()),
    __param(2, common_1.Param('universeName')),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, Object, String]),
    __metadata("design:returntype", Promise)
], StatusController.prototype, "get", null);
__decorate([
    common_1.Get('universe/:universeName/project/:projectName'),
    __param(0, common_1.Req()),
    __param(1, common_1.Res()),
    __param(2, common_1.Param('universeName')),
    __param(3, common_1.Param('projectName')),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, Object, String, String]),
    __metadata("design:returntype", Promise)
], StatusController.prototype, "getByProjectName", null);
StatusController = __decorate([
    common_1.UseGuards(authGuard_1.AuthGuard),
    common_1.Controller('status'),
    __metadata("design:paramtypes", [logger_service_1.LoggerService,
        status_service_1.StatusService,
        universe_service_1.UniverseService,
        config_service_1.ConfigService])
], StatusController);
exports.StatusController = StatusController;
//# sourceMappingURL=status.controller.js.map