"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.StatusService = void 0;
const common_1 = require("@nestjs/common");
const queue_service_1 = require("../queue/queue.service");
const binary_service_1 = require("../binary/binary.service");
const symbol_server_logs_service_1 = require("../symbol-server-logs/symbol-server-logs.service");
let StatusService = class StatusService {
    constructor(_queueService, _binaryService, _symbolServerLogs) {
        this._queueService = _queueService;
        this._binaryService = _binaryService;
        this._symbolServerLogs = _symbolServerLogs;
    }
    async getSymbolInformation(universeName, projectName, symbolName, debugId) {
        const processingData = this.getProcessingData(universeName, projectName);
        const logs = await this._symbolServerLogs.getByTextAndUniverseData(universeName, projectName, `symbol: ${symbolName} debugId: ${debugId}`);
        return {
            logs,
            status: this._queueService.getSymbolStatus(symbolName, debugId),
            processingData: processingData && processingData.currentSymbol === `${symbolName},${debugId}`
                ? processingData
                : undefined,
        };
    }
    getStatus(universeName) {
        return {
            inQueue: this.getQueueStatus(universeName),
            processing: this.getProcessingData(universeName),
        };
    }
    getStatusForProject(universeName, projectName) {
        return {
            inQueue: this.getQueueStatus(universeName, projectName),
            processing: this.getProcessingData(universeName, projectName),
        };
    }
    getProcessingData(universeName, projectName) {
        const currentEvent = this._binaryService.CurrentSymbol;
        if (!currentEvent) {
            return undefined;
        }
        if ((!!projectName &&
            currentEvent.event.project === projectName &&
            currentEvent.event.universe === universeName) ||
            (!projectName && currentEvent.event.universe === universeName)) {
            return {
                currentSymbol: currentEvent.missingSymbol,
                status: this._binaryService.downloadTasks,
            };
        }
        return undefined;
    }
    getQueueStatus(universeName, projectName) {
        return this._queueService
            .getEventStack()
            .filter((n) => (!!projectName && n.project === projectName) ||
            (!projectName && n.universe === universeName));
    }
};
StatusService = __decorate([
    common_1.Injectable(),
    __metadata("design:paramtypes", [queue_service_1.QueueService,
        binary_service_1.BinaryService,
        symbol_server_logs_service_1.SymbolServerLogsService])
], StatusService);
exports.StatusService = StatusService;
//# sourceMappingURL=status.service.js.map