"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SymbolItemService = void 0;
const common_1 = require("@nestjs/common");
const typeorm_1 = require("@nestjs/typeorm");
const path_1 = require("path");
const typeorm_2 = require("typeorm");
const symbolItem_1 = require("../../database/entities/symbolItem");
const symbolItemType_1 = require("../../database/entities/types/symbolItemType");
const config_service_1 = require("../config/config.service");
const logger_service_1 = require("../logger/logger.service");
const symbol_server_service_1 = require("../symbol-server/symbol-server.service");
const symbol_item_cache_service_1 = require("./symbol-item-cache.service");
let SymbolItemService = class SymbolItemService {
    constructor(_symbolItemCacheService, _symbolItemRepository, _configService, _symbolServerService, _logger) {
        this._symbolItemCacheService = _symbolItemCacheService;
        this._symbolItemRepository = _symbolItemRepository;
        this._configService = _configService;
        this._symbolServerService = _symbolServerService;
        this._logger = _logger;
    }
    async getByTextWithProjectValidation(config, req, res, symbolServerId, text, type, page = 0, take = 0) {
        await this._symbolServerService.validateSymbolServerAccessWithProjectAccess(config, req, res, symbolServerId);
        return await this._symbolItemRepository
            .createQueryBuilder('symbolItem')
            .where(`symbolItem.symbolServerId = :symbolServerId 
        AND symbolItem.type = :type
        AND (symbolItem.symbolName like :text OR symbolItem.debugId like :text)`, {
            symbolServerId,
            type,
            text: `%${text}%`,
        })
            .orderBy('symbolItem.creationDate', 'DESC')
            .skip(page * take)
            .take(take)
            .getManyAndCount();
    }
    async deleteByTextWithProjectValidation(config, req, res, symbolServerId, text, type) {
        await this._symbolServerService.validateSymbolServerAccessWithProjectAccess(config, req, res, symbolServerId);
        this._symbolItemCacheService.clear();
        await this._symbolItemRepository
            .createQueryBuilder()
            .delete()
            .from(symbolItem_1.SymbolItem, 'symbolItem')
            .where(`symbol_item.symbolServerId = :symbolServerId 
        AND symbol_item.type = :type
        AND (symbol_item.symbolName like :text OR symbol_item.debugId like :text)`, {
            symbolServerId,
            type,
            text: `%${text}%`,
        })
            .execute();
    }
    async getById(symbolItemId, type) {
        if (!symbolItemId) {
            return undefined;
        }
        return await this._symbolItemRepository.findOne({
            where: {
                id: symbolItemId,
                type,
            },
        });
    }
    async add(symbolItem) {
        const symbolServerExists = await this._symbolServerService.exists(symbolItem.symbolServerId);
        if (!symbolServerExists) {
            throw new common_1.BadRequestException(`Symbol server with id ${symbolItem.symbolServerId} doesn't exists`);
        }
        this._logger.info(`Adding new symbol item to list. Data: ${JSON.stringify(symbolItem)}`);
        const entity = this._symbolItemRepository.create(symbolItem);
        return await this._symbolItemRepository.save(entity);
    }
    async addCollectionWithProjectValidation(config, req, res, symbolItem, symbolServerId, type, force = false) {
        if (force === false) {
            await this._symbolServerService.validateSymbolServerAccessWithProjectAccess(config, req, res, symbolServerId);
        }
        else {
            this._configService.identityManager.bypassProjectAccessCheck(res);
        }
        if (!symbolItem || symbolItem.length === 0) {
            throw new common_1.BadRequestException(`No symbols to add`);
        }
        this._logger.info(`Adding a collection of elements to symbol item list. Count: ${symbolItem.length}`);
        const collection = symbolItem
            .filter((n) => !!n)
            .map((name) => {
            if (!name) {
                return;
            }
            return {
                type,
                symbolServerId,
                symbolName: name,
            };
        });
        if (collection.length === 0) {
            throw new common_1.BadRequestException(`No symbols to add`);
        }
        await this._symbolItemRepository.save(collection, { chunk: 100 });
    }
    async addCollection(symbolItem, symbolServerId, type, auth, force = false) {
        if (force === false) {
            await this._symbolServerService.validateSymbolServerAcceess(symbolServerId, auth);
        }
        if (!symbolItem || symbolItem.length === 0) {
            throw new common_1.BadRequestException(`No symbols to add`);
        }
        this._logger.info(`Adding a collection of elements to symbol item list. Count: ${symbolItem.length}`);
        const collection = symbolItem
            .filter((n) => !!n)
            .map((name) => {
            if (!name) {
                return;
            }
            return {
                type,
                symbolServerId,
                symbolName: name,
            };
        });
        if (collection.length === 0) {
            throw new common_1.BadRequestException(`No symbols to add`);
        }
        await this._symbolItemRepository.save(collection, { chunk: 100 });
    }
    async skipSymbol(symbolName, debugId, symbolServerId) {
        const total = await this._symbolItemRepository.count({
            join: {
                alias: 'symbol',
                leftJoin: {
                    symbolServer: 'symbol.symbolServer',
                },
            },
            where: [
                {
                    debugId,
                    symbolName,
                    type: symbolItemType_1.SymbolItemType.SkipList,
                    symbolServer: {
                        id: symbolServerId,
                    },
                },
                {
                    symbolName,
                    type: symbolItemType_1.SymbolItemType.BlackList,
                    symbolServer: {
                        id: symbolServerId,
                    },
                },
            ],
        });
        return total > 0;
    }
    async findAll() {
        return await this._symbolItemRepository.find();
    }
    async find(type) {
        return await this._symbolItemRepository.find({
            where: {
                type,
            },
        });
    }
    async findByNameAndDebugIdInSymbolServers(symbolName, debugId, type, symbolServerIds, ignoreHidden = true) {
        if (!symbolServerIds || symbolServerIds.length === 0) {
            return [];
        }
        const conditions = [
            {
                symbolName,
                debugId,
                type,
                id: typeorm_2.In(symbolServerIds),
                hidden: false,
            },
            {
                symbolName: path_1.basename(symbolName, path_1.extname(symbolName)),
                debugId,
                type,
                id: typeorm_2.In(symbolServerIds),
                hidden: false,
            },
        ];
        if (!ignoreHidden) {
            for (const condition of conditions) {
                delete condition.hidden;
            }
        }
        return await this._symbolItemRepository.find({
            join: {
                alias: 'symbol',
                leftJoin: {
                    symbolServer: 'symbol.symbolServer',
                },
            },
            where: conditions,
        });
    }
    async findOne(symbolName, symbolServerId, type) {
        return await this._symbolItemRepository.findOne({
            where: {
                symbolName,
                symbolServerId,
                type,
            },
        });
    }
    async getBySymbolServerIdWithProjectValidation(config, req, res, symbolServerId, type, page = 0, take = 10) {
        await this._symbolServerService.validateSymbolServerAccessWithProjectAccess(config, req, res, symbolServerId);
        return await this._symbolItemRepository.findAndCount({
            skip: page * take,
            take,
            where: {
                type,
                symbolServer: {
                    id: symbolServerId,
                },
            },
        });
    }
    async getAllBySymbolServerId(symbolServerId) {
        const result = await this._symbolItemRepository.find({
            where: {
                symbolServer: {
                    id: symbolServerId,
                },
            },
        });
        return result;
    }
    async removeWithProjectValidation(config, req, res, symbolId, type) {
        const symbol = await this._symbolItemRepository.findOne(symbolId);
        if (!symbol) {
            throw new common_1.NotFoundException();
        }
        this._symbolItemCacheService.clear();
        await this._symbolServerService.validateSymbolServerAccessWithProjectAccess(config, req, res, symbol.symbolServerId);
        await this._symbolItemRepository.delete({
            id: symbolId,
            type,
        });
    }
    async removeAllWithProjectValidation(config, req, res, symbolServerId, type) {
        this._symbolItemCacheService.clear();
        await this._symbolServerService.validateSymbolServerAccessWithProjectAccess(config, req, res, symbolServerId);
        await this._symbolItemRepository.delete({
            symbolServerId,
            type,
        });
    }
};
SymbolItemService = __decorate([
    common_1.Injectable(),
    __param(1, typeorm_1.InjectRepository(symbolItem_1.SymbolItem)),
    __param(3, common_1.Inject(common_1.forwardRef(() => symbol_server_service_1.SymbolServerService))),
    __metadata("design:paramtypes", [symbol_item_cache_service_1.SymbolItemCacheService,
        typeorm_2.Repository,
        config_service_1.ConfigService,
        symbol_server_service_1.SymbolServerService,
        logger_service_1.LoggerService])
], SymbolItemService);
exports.SymbolItemService = SymbolItemService;
//# sourceMappingURL=symbol-item.service.js.map