"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SymbolServerPriorityController = void 0;
const common_1 = require("@nestjs/common");
const authGuard_1 = require("../../guards/authGuard");
const config_service_1 = require("../config/config.service");
const project_service_1 = require("../project/project.service");
const symbol_server_service_1 = require("../symbol-server/symbol-server.service");
const setPriorities_1 = require("./dto/setPriorities");
const symbol_server_priority_service_1 = require("./symbol-server-priority.service");
let SymbolServerPriorityController = class SymbolServerPriorityController {
    constructor(_symbolServerPriorityService, _configService, _symbolServerService, _projectService) {
        this._symbolServerPriorityService = _symbolServerPriorityService;
        this._configService = _configService;
        this._symbolServerService = _symbolServerService;
        this._projectService = _projectService;
    }
    async updateProjectPriotity(req, res, universeName, projectName, model) {
        if (!this._configService.identityManager.checkProjectAccess(req, res, [projectName])) {
            return res.send();
        }
        await this._symbolServerPriorityService.update(universeName, projectName, model.priorities);
        res.send({
            statusCode: 200,
            message: 'ok',
            err: undefined,
        });
    }
    async updateUniversePriotity(req, res, universeName, model) {
        const promises = model.priorities.map(async (priorityObject) => {
            const server = await this._symbolServerService.getById(priorityObject.symbolServerId);
            return server === null || server === void 0 ? void 0 : server.projectId;
        });
        let requestedServersProjectIds = await Promise.all(promises);
        requestedServersProjectIds = requestedServersProjectIds.filter((id) => {
            return !!id;
        });
        if (requestedServersProjectIds.length > 0) {
            const projectIds = Array.from(new Set(requestedServersProjectIds));
            const projectNames = [];
            for (const projectId of projectIds) {
                if (projectId) {
                    const projectName = await this._projectService.getProjectNameById(projectId);
                    if (projectName) {
                        projectNames.push(projectName);
                    }
                }
            }
            this._configService.identityManager.checkProjectAccess(req, res, projectNames);
        }
        else {
            this._configService.identityManager.bypassProjectAccessCheck(res);
        }
        await this._symbolServerPriorityService.update(universeName, '', model.priorities);
        res.send({
            statusCode: 200,
            message: 'ok',
            err: undefined,
        });
    }
};
__decorate([
    common_1.Post('universe/:universeName/project/:projectName'),
    __param(0, common_1.Req()),
    __param(1, common_1.Res()),
    __param(2, common_1.Param('universeName')),
    __param(3, common_1.Param('projectName')),
    __param(4, common_1.Body(new common_1.ValidationPipe({ transform: true }))),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, Object, String, String, setPriorities_1.SetPriorities]),
    __metadata("design:returntype", Promise)
], SymbolServerPriorityController.prototype, "updateProjectPriotity", null);
__decorate([
    common_1.Post('universe/:universeName'),
    __param(0, common_1.Req()),
    __param(1, common_1.Res()),
    __param(2, common_1.Param('universeName')),
    __param(3, common_1.Body(new common_1.ValidationPipe({ transform: true }))),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, Object, String, setPriorities_1.SetPriorities]),
    __metadata("design:returntype", Promise)
], SymbolServerPriorityController.prototype, "updateUniversePriotity", null);
SymbolServerPriorityController = __decorate([
    common_1.Controller('symbolServer/priority'),
    common_1.UseGuards(authGuard_1.AuthGuard),
    __metadata("design:paramtypes", [symbol_server_priority_service_1.SymbolServerPriorityService,
        config_service_1.ConfigService,
        symbol_server_service_1.SymbolServerService,
        project_service_1.ProjectService])
], SymbolServerPriorityController);
exports.SymbolServerPriorityController = SymbolServerPriorityController;
//# sourceMappingURL=symbol-server-priority.controller.js.map