"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SymbolServerPriorityService = void 0;
const common_1 = require("@nestjs/common");
const typeorm_1 = require("@nestjs/typeorm");
const symbolServerPriority_1 = require("../../database/entities/symbolServerPriority");
const typeorm_2 = require("typeorm");
const project_service_1 = require("../project/project.service");
const universe_service_1 = require("../universe/universe.service");
const symbol_server_service_1 = require("../symbol-server/symbol-server.service");
let SymbolServerPriorityService = class SymbolServerPriorityService {
    constructor(_symbolServerPriorityRepository, _projectService, _symbolServerService, _universeService) {
        this._symbolServerPriorityRepository = _symbolServerPriorityRepository;
        this._projectService = _projectService;
        this._symbolServerService = _symbolServerService;
        this._universeService = _universeService;
    }
    async update(universeName, projectName, priorities) {
        const priorityEntities = await this._symbolServerPriorityRepository
            .createQueryBuilder('priority')
            .leftJoin('priority.project', 'project')
            .leftJoin('project.universe', 'projectUniverse')
            .leftJoin('priority.universe', 'universe')
            .leftJoin('priority.symbolServer', 'symbolServer')
            .where(`${projectName
            ? `priority.projectId IS NOT NULL 
                AND  project.name= :name 
                AND projectUniverse.name = :universeName`
            : 'priority.universeId IS NOT NULL AND universe.name= :name'}
        `, { name: projectName ? projectName : universeName, universeName })
            .getMany();
        if (priorityEntities.length === 0) {
            return await this.create(projectName, universeName, priorities);
        }
        const prioritiesToAdd = [];
        for (let index = 0; index < priorities.length; index++) {
            const priority = priorities[index];
            const currentPriority = priorityEntities.filter((n) => n.symbolServerId === priority.symbolServerId);
            if (!currentPriority || currentPriority.length === 0) {
                prioritiesToAdd.push(priority);
                continue;
            }
            currentPriority[0].priority = priority.priority;
        }
        if (prioritiesToAdd.length !== 0) {
            await this.create(projectName, universeName, prioritiesToAdd);
        }
        await this._symbolServerPriorityRepository.save(priorityEntities);
    }
    async create(projectName, universeName, priorities) {
        if (!priorities || priorities.length === 0) {
            return;
        }
        const priorityBase = {};
        if (projectName) {
            const project = await this._projectService.getByProjectName(projectName, universeName);
            if (project) {
                priorityBase.projectId = project.id;
            }
        }
        if (universeName && !priorityBase.projectId) {
            const universe = await this._universeService.getByUniverseName(universeName);
            if (universe) {
                priorityBase.universeId = universe.id;
            }
            else {
                return;
            }
        }
        const priorityEntities = [];
        for (const priority of priorities) {
            const symbolServerExists = await this._symbolServerService.exists(priority.symbolServerId);
            if (!symbolServerExists) {
                throw new common_1.BadRequestException(`Symbol server with id ${priority.symbolServerId} doesn't exists`);
            }
            priorityEntities.push(Object.assign(priority, priorityBase));
        }
        await this._symbolServerPriorityRepository.save(priorityEntities);
    }
};
SymbolServerPriorityService = __decorate([
    common_1.Injectable(),
    __param(0, typeorm_1.InjectRepository(symbolServerPriority_1.SymbolServerPriority)),
    __metadata("design:paramtypes", [typeorm_2.Repository,
        project_service_1.ProjectService,
        symbol_server_service_1.SymbolServerService,
        universe_service_1.UniverseService])
], SymbolServerPriorityService);
exports.SymbolServerPriorityService = SymbolServerPriorityService;
//# sourceMappingURL=symbol-server-priority.service.js.map