"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SymbolServerController = void 0;
const common_1 = require("@nestjs/common");
const platform_express_1 = require("@nestjs/platform-express");
const fs_extra_1 = require("fs-extra");
const authHelper_1 = require("../../helpers/authHelper");
const parseIntArray_1 = require("../../pipes/parseIntArray");
const parseOptionalInt_1 = require("../../pipes/parseOptionalInt");
const config_service_1 = require("../config/config.service");
const logger_service_1 = require("../logger/logger.service");
const project_service_1 = require("../project/project.service");
const universe_service_1 = require("../universe/universe.service");
const authGuard_1 = require("./../../guards/authGuard");
const createSymbolServer_1 = require("./dto/createSymbolServer");
const updateSymbolServer_1 = require("./dto/updateSymbolServer");
const serverCredentialsPipe_1 = require("./pipes/serverCredentialsPipe");
const updateServerCredentialsPipe_1 = require("./pipes/updateServerCredentialsPipe");
const symbol_server_service_1 = require("./symbol-server.service");
let SymbolServerController = class SymbolServerController {
    constructor(_logger, _symbolServerService, _universeService, _projectService, _configService) {
        this._logger = _logger;
        this._symbolServerService = _symbolServerService;
        this._universeService = _universeService;
        this._projectService = _projectService;
        this._configService = _configService;
    }
    async getByUniverseName(req, res, universeName, page, take) {
        if (!authHelper_1.AuthHelper.checkUserAccess(req.coronerAuth, universeName)) {
            this._configService.identityManager.bypassProjectAccessCheck(res);
            this._logger.warn(`User without access to universe tried to retrieve data. ${universeName}}`);
            throw new common_1.UnauthorizedException();
        }
        this._logger.info(`Returning ${take || 10} symbol servers for universe ${universeName}
       from page ${page || 0}, `);
        const results = await this._symbolServerService.getByUniverseName(universeName, page, take);
        return await this.validateSymbolServerAccess(req, res, results);
    }
    async getByProjectName(req, res, universeName, projectName, page, take) {
        if (!authHelper_1.AuthHelper.checkUserAccess(req.coronerAuth, universeName)) {
            this._configService.identityManager.bypassProjectAccessCheck(res);
            this._logger.warn(`User without access to universe tried to retrieve data. ${universeName} ${projectName} `);
            throw new common_1.UnauthorizedException();
        }
        this._logger.info(`Returning ${take || 10} symbol servers for universe 
      ${universeName} and project ${projectName} from page ${page || 0}`);
        const results = await this._symbolServerService.getByProjectName(universeName, projectName, page, take);
        return await this.validateSymbolServerAccess(req, res, results);
    }
    async getDetails(req, res, symbolServerId) {
        const symbolServer = await this._symbolServerService.getById(symbolServerId);
        if (symbolServer === null || symbolServer === void 0 ? void 0 : symbolServer.projectId) {
            const projectName = await this._projectService.getProjectNameById(symbolServer.projectId);
            if (!projectName) {
                throw new common_1.UnauthorizedException('Invalid project id');
            }
            this._configService.identityManager.checkProjectAccess(req, res, [projectName]);
        }
        else {
            this._configService.identityManager.bypassProjectAccessCheck(res);
        }
        if (!symbolServer ||
            (symbolServer.hidden && authHelper_1.AuthHelper.isSuperUser(req.coronerAuth) === false)) {
            throw new common_1.NotFoundException();
        }
        if (symbolServer.hidden) {
            throw new common_1.NotFoundException();
        }
        if (!symbolServer.projectId && !symbolServer.universeId) {
            res.send(symbolServer);
            return;
        }
        const universeName = symbolServer.project
            ? symbolServer.project.universe.name
            : symbolServer.universe.name;
        if (!authHelper_1.AuthHelper.checkUserAccess(req.coronerAuth, universeName)) {
            this._logger.warn(`User without access to universe tried to create symbol server.
         universe name: ${universeName} symbol server id${symbolServerId} `);
            throw new common_1.UnauthorizedException();
        }
        this._logger.info(`Return symbol server ${symbolServerId}`);
        res.send(symbolServer);
    }
    async statuses(req, res, model) {
        this._configService.identityManager.bypassProjectAccessCheck(res);
        const results = await this._symbolServerService.fetchStatuses(model.data);
        res.send(results);
    }
    async validateSymbolServer({ coronerAuth }, res, secretFile, model) {
        var _a;
        this._configService.identityManager.bypassProjectAccessCheck(res);
        if (!model.query) {
            this._logger.info(`User tried to validate symbol server without symbol server url`);
            throw new common_1.BadRequestException('Missing sample url');
        }
        if (!coronerAuth) {
            this._logger.info(`Unauthorized user tried to execute validate action`);
            throw new common_1.UnauthorizedException();
        }
        if ((model.serverCredentials && !(secretFile === null || secretFile === void 0 ? void 0 : secretFile.path)) || !model.serverCredentials) {
            this._logger.info(`User tried to submit Google Cloud Platform Symbol Server without secret file or without server credentials`);
            throw new common_1.BadRequestException('Missing GCP Secret file or missing server credentials');
        }
        this._logger.info(`User ${(_a = coronerAuth.cfg) === null || _a === void 0 ? void 0 : _a.username} validating symbol server connection`);
        const result = await this._symbolServerService.validate(model.query, model, secretFile === null || secretFile === void 0 ? void 0 : secretFile.path);
        if (secretFile === null || secretFile === void 0 ? void 0 : secretFile.path) {
            await fs_extra_1.remove(secretFile.path);
        }
        res.send(result);
    }
    async createProjectSymbolServer(req, res, universeName, projectName, secretFile, model) {
        if (!this._configService.identityManager.checkProjectAccess(req, res, [projectName])) {
            res.send();
            return;
        }
        if (!authHelper_1.AuthHelper.checkUserAccess(req.coronerAuth, universeName)) {
            this._logger.warn(`User without access to universe tried to create symbol server.
         ${universeName} ${projectName} `);
            throw new common_1.UnauthorizedException();
        }
        const universe = await this._universeService.fetchOrTryAdd(universeName, projectName);
        if (!universe || !universe.project || universe.project.length === 0) {
            throw new common_1.BadRequestException(`Universe/Project doesn't exists`);
        }
        const project = universe.project[0];
        model.projectId = project.id;
        this._logger.info(`Adding new symbol server to database. Data: ${JSON.stringify(model)}`);
        if (!model.serverCredentials && (secretFile === null || secretFile === void 0 ? void 0 : secretFile.path)) {
            throw new common_1.BadRequestException('Missing GCP Secret file');
        }
        const result = await this._symbolServerService.add(model);
        res.send({
            id: result.id,
        });
    }
    async createUniverseSymbolServer({ coronerAuth }, res, universeName, secretFile, model) {
        this._configService.identityManager.bypassProjectAccessCheck(res);
        if (!authHelper_1.AuthHelper.checkUserAccess(coronerAuth, universeName)) {
            this._logger.warn(`User without access to universe tried to create symbol server.
         ${universeName}`);
            throw new common_1.UnauthorizedException();
        }
        if (!model.serverCredentials && (secretFile === null || secretFile === void 0 ? void 0 : secretFile.path)) {
            throw new common_1.BadRequestException('Missing GCP Secret file');
        }
        const universe = await this._universeService.fetchOrTryAdd(universeName);
        if (!universe) {
            throw new common_1.BadRequestException(`Universe doesn't exists`);
        }
        model.universeId = universe.id;
        this._logger.info(`Adding new symbol server to database. Data: ${JSON.stringify(model)}`);
        const result = await this._symbolServerService.add(model);
        res.send({
            id: result.id,
        });
    }
    async update(req, res, id, model, _) {
        await this._symbolServerService.validateSymbolServerAccessWithProjectAccess(this._configService, req, res, id);
        this._logger.info(`Updating symbol server with id ${id}. Data: ${JSON.stringify(model)}`);
        await this._symbolServerService.update(id, model);
        res.send({
            statusCode: 200,
            message: 'updated',
            err: undefined,
        });
    }
    async enable(req, res, id) {
        await this._symbolServerService.validateSymbolServerAccessWithProjectAccess(this._configService, req, res, id);
        this._logger.info(`Enabling symbol server with id ${id}.`);
        await this._symbolServerService.toggle(id);
        res.send({
            statusCode: 200,
            message: 'ok',
            err: undefined,
        });
    }
    async disable(req, res, id) {
        await this._symbolServerService.validateSymbolServerAccessWithProjectAccess(this._configService, req, res, id);
        this._logger.info(`Disabling symbol server with id ${id}.`);
        await this._symbolServerService.toggle(id, true);
        res.send({
            statusCode: 200,
            message: 'ok',
            err: undefined,
        });
    }
    async delete(req, res, id) {
        await this._symbolServerService.validateSymbolServerAccessWithProjectAccess(this._configService, req, res, id);
        this._logger.info(`Trying to remove symbol server with id ${id}`);
        await this._symbolServerService.remove(id, false);
        res.send({
            statusCode: 200,
            message: 'ok',
            err: undefined,
        });
    }
    async validateSymbolServerAccess(req, res, results) {
        const symbolServerprojectIds = results[0]
            .map((server) => {
            return server.projectId;
        })
            .filter((id) => {
            return !!id;
        });
        if (symbolServerprojectIds.length === 0) {
            this._configService.identityManager.bypassProjectAccessCheck(res);
            res.send(results);
            return;
        }
        const projectIds = Array.from(new Set(symbolServerprojectIds));
        const projectNames = [];
        for (const projectId of projectIds) {
            if (projectId) {
                const projectName = await this._projectService.getProjectNameById(projectId);
                if (projectName) {
                    projectNames.push(projectName);
                }
            }
        }
        this._configService.identityManager.checkProjectAccess(req, res, projectNames);
        res.send(results);
    }
};
__decorate([
    common_1.Get('universe/:universeName'),
    __param(0, common_1.Req()),
    __param(1, common_1.Res()),
    __param(2, common_1.Param('universeName')),
    __param(3, common_1.Query('page', new parseOptionalInt_1.ParseOptionalIntPipe())),
    __param(4, common_1.Query('take', new parseOptionalInt_1.ParseOptionalIntPipe())),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, Object, String, Object, Object]),
    __metadata("design:returntype", Promise)
], SymbolServerController.prototype, "getByUniverseName", null);
__decorate([
    common_1.Get('universe/:universeName/project/:projectName'),
    __param(0, common_1.Req()),
    __param(1, common_1.Res()),
    __param(2, common_1.Param('universeName')),
    __param(3, common_1.Param('projectName')),
    __param(4, common_1.Query('page', new parseOptionalInt_1.ParseOptionalIntPipe())),
    __param(5, common_1.Query('take', new parseOptionalInt_1.ParseOptionalIntPipe())),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, Object, String, String, Object, Object]),
    __metadata("design:returntype", Promise)
], SymbolServerController.prototype, "getByProjectName", null);
__decorate([
    common_1.Get('details/:symbolServerId'),
    __param(0, common_1.Req()),
    __param(1, common_1.Res()),
    __param(2, common_1.Param('symbolServerId', new common_1.ParseIntPipe())),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, Object, Number]),
    __metadata("design:returntype", Promise)
], SymbolServerController.prototype, "getDetails", null);
__decorate([
    common_1.Post('statuses'),
    __param(0, common_1.Req()),
    __param(1, common_1.Res()),
    __param(2, common_1.Body(new parseIntArray_1.ParseIntArrayPipe())),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, Object, Object]),
    __metadata("design:returntype", Promise)
], SymbolServerController.prototype, "statuses", null);
__decorate([
    common_1.Post('validate'),
    common_1.HttpCode(200),
    common_1.UseInterceptors(platform_express_1.FileInterceptor('secretFile')),
    __param(0, common_1.Req()),
    __param(1, common_1.Res()),
    __param(2, common_1.UploadedFile()),
    __param(3, common_1.Body(serverCredentialsPipe_1.ServerCredentialsPipe)),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, Object, Object, Object]),
    __metadata("design:returntype", Promise)
], SymbolServerController.prototype, "validateSymbolServer", null);
__decorate([
    common_1.Post('universe/:universeName/project/:projectName'),
    common_1.UseInterceptors(platform_express_1.FileInterceptor('secretFile')),
    __param(0, common_1.Req()),
    __param(1, common_1.Res()),
    __param(2, common_1.Param('universeName')),
    __param(3, common_1.Param('projectName')),
    __param(4, common_1.UploadedFile()),
    __param(5, common_1.Body(serverCredentialsPipe_1.ServerCredentialsPipe)),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, Object, String, String, Object, createSymbolServer_1.CreateSymbolServer]),
    __metadata("design:returntype", Promise)
], SymbolServerController.prototype, "createProjectSymbolServer", null);
__decorate([
    common_1.Post('universe/:universeName/'),
    common_1.UseInterceptors(platform_express_1.FileInterceptor('secretFile')),
    __param(0, common_1.Req()),
    __param(1, common_1.Res()),
    __param(2, common_1.Param('universeName')),
    __param(3, common_1.UploadedFile()),
    __param(4, common_1.Body(serverCredentialsPipe_1.ServerCredentialsPipe)),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, Object, String, Object, createSymbolServer_1.CreateSymbolServer]),
    __metadata("design:returntype", Promise)
], SymbolServerController.prototype, "createUniverseSymbolServer", null);
__decorate([
    common_1.Put(':symbolServerId'),
    common_1.UseInterceptors(platform_express_1.FileInterceptor('secretFile')),
    common_1.UsePipes(),
    __param(0, common_1.Req()),
    __param(1, common_1.Res()),
    __param(2, common_1.Param('symbolServerId', new common_1.ParseIntPipe())),
    __param(3, common_1.Body(updateServerCredentialsPipe_1.UpdateServerCredentialsPipe)),
    __param(4, common_1.UploadedFile()),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, Object, Number, updateSymbolServer_1.UpdateSymbolServer, Object]),
    __metadata("design:returntype", Promise)
], SymbolServerController.prototype, "update", null);
__decorate([
    common_1.Put(':symbolServerId/enable'),
    __param(0, common_1.Req()),
    __param(1, common_1.Res()),
    __param(2, common_1.Param('symbolServerId', new common_1.ParseIntPipe())),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, Object, Number]),
    __metadata("design:returntype", Promise)
], SymbolServerController.prototype, "enable", null);
__decorate([
    common_1.Put(':symbolServerId/disable'),
    __param(0, common_1.Req()),
    __param(1, common_1.Res()),
    __param(2, common_1.Param('symbolServerId', new common_1.ParseIntPipe())),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, Object, Number]),
    __metadata("design:returntype", Promise)
], SymbolServerController.prototype, "disable", null);
__decorate([
    common_1.Delete(':symbolServerId'),
    __param(0, common_1.Req()),
    __param(1, common_1.Res()),
    __param(2, common_1.Param('symbolServerId', new common_1.ParseIntPipe())),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, Object, Number]),
    __metadata("design:returntype", Promise)
], SymbolServerController.prototype, "delete", null);
SymbolServerController = __decorate([
    common_1.Controller('symbolServer'),
    common_1.UseGuards(authGuard_1.AuthGuard),
    __metadata("design:paramtypes", [logger_service_1.LoggerService,
        symbol_server_service_1.SymbolServerService,
        universe_service_1.UniverseService,
        project_service_1.ProjectService,
        config_service_1.ConfigService])
], SymbolServerController);
exports.SymbolServerController = SymbolServerController;
//# sourceMappingURL=symbol-server.controller.js.map