"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SymbolServerService = void 0;
const common_1 = require("@nestjs/common");
const axios_1 = __importDefault(require("axios"));
const symbolServer_1 = require("../../database/entities/symbolServer");
const typeorm_1 = require("typeorm");
const typeorm_2 = require("@nestjs/typeorm");
const proxy_service_1 = require("../proxy/proxy.service");
const server_credentials_service_1 = require("../server-credentials/server-credentials.service");
const symbol_item_service_1 = require("../symbol-item/symbol-item.service");
const symbolItemType_1 = require("../../database/entities/types/symbolItemType");
const universe_service_1 = require("../universe/universe.service");
const logger_service_1 = require("../logger/logger.service");
const authHelper_1 = require("../../helpers/authHelper");
const path = __importStar(require("path"));
const symbolItem_1 = require("../../database/entities/symbolItem");
const fs_extra_1 = require("fs-extra");
const credentialsType_1 = require("../../database/entities/types/credentialsType");
const aws_sdk_1 = require("aws-sdk");
const storage_1 = require("@google-cloud/storage");
let SymbolServerService = class SymbolServerService {
    constructor(_symbolServerRepository, _proxyService, _serverCredentialsService, _whiteListService, _universeService, _logger) {
        this._symbolServerRepository = _symbolServerRepository;
        this._proxyService = _proxyService;
        this._serverCredentialsService = _serverCredentialsService;
        this._whiteListService = _whiteListService;
        this._universeService = _universeService;
        this._logger = _logger;
    }
    async addWhiteList(id, whiteList) {
        await this._whiteListService.addCollection(whiteList, id, symbolItemType_1.SymbolItemType.WhiteList, undefined, true);
    }
    async validateSymbolServerAcceess(symbolServerId, coronerAuth) {
        if (!coronerAuth) {
            throw new common_1.UnauthorizedException();
        }
        if (!symbolServerId) {
            throw new common_1.BadRequestException('Symbol server id is not defined');
        }
        const symbolServer = await this.getById(symbolServerId);
        if (!symbolServer || symbolServer.hidden) {
            throw new common_1.NotFoundException();
        }
        if (!symbolServer.projectId) {
            return;
        }
        const universeName = symbolServer.project
            ? symbolServer.project.universe.name
            : symbolServer.universe.name;
        if (!authHelper_1.AuthHelper.checkUserAccess(coronerAuth, universeName)) {
            this._logger.warn(`User without access tried to fetch information symbol server.
         universe name: ${universeName} symbol server id${symbolServerId} `);
            throw new common_1.UnauthorizedException();
        }
    }
    async validateSymbolServerAccessWithProjectAccess(config, req, res, symbolServerId) {
        var _a;
        if (!req.coronerAuth) {
            config.identityManager.bypassProjectAccessCheck(res);
            throw new common_1.UnauthorizedException();
        }
        if (!symbolServerId) {
            config.identityManager.bypassProjectAccessCheck(res);
            throw new common_1.BadRequestException('Symbol server id is not defined');
        }
        const symbolServer = await this.getById(symbolServerId);
        if (!symbolServer || symbolServer.hidden) {
            config.identityManager.bypassProjectAccessCheck(res);
            throw new common_1.NotFoundException();
        }
        if (!symbolServer.projectId || !symbolServer.project) {
            config.identityManager.bypassProjectAccessCheck(res);
            return;
        }
        const universeName = symbolServer.project
            ? symbolServer.project.universe.name
            : symbolServer.universe.name;
        if (!authHelper_1.AuthHelper.checkUserAccess(req.coronerAuth, universeName)) {
            this._logger.warn(`User without access tried to fetch information symbol server.
         universe name: ${universeName} symbol server id${symbolServerId} `);
            config.identityManager.bypassProjectAccessCheck(res);
            throw new common_1.UnauthorizedException();
        }
        if (!config.identityManager.checkProjectAccess(req, res, [(_a = symbolServer.project) === null || _a === void 0 ? void 0 : _a.name])) {
            throw new common_1.UnauthorizedException();
        }
    }
    async getAllByProjectName(universeId, projectId, symbolName, debugId) {
        return await this._symbolServerRepository
            .createQueryBuilder('symbolServer')
            .leftJoinAndSelect('symbolServer.statistics', 'statistics')
            .leftJoinAndSelect('symbolServer.proxy', 'proxy')
            .leftJoinAndSelect('symbolServer.serverCredentials', 'serverCredentials')
            .leftJoin('symbolServer.symbolItem', 'symbolItem')
            .addSelect('proxy.password')
            .addSelect('serverCredentials.password')
            .leftJoinAndSelect('symbolServer.priorities', 'priority', !!projectId ? 'priority.projectId = :projectId' : 'priority.universeId = :projectId', {
            projectId: projectId || universeId,
        })
            .where(`(
        (symbolServer.projectId is NULL and symbolServer.universeId is NULL)
        OR ${!!projectId
            ? `(symbolServer.universeId = ${universeId}
              AND symbolServer.projectId is NULL)
              OR symbolServer.projectId = :projectId`
            : 'symbolServer.universeId = :projectId'})
        AND symbolServer.disable = 0`, {
            projectId: projectId || universeId,
        })
            .andWhere((qb) => {
            const subQuery = qb
                .subQuery()
                .select('DISTINCT symbolItem.symbolServerId')
                .from(symbolItem_1.SymbolItem, 'symbolItem')
                .where(`
            (symbolItem.type = 0 OR symbolItem.type=2) AND 
          (symbolItem.symbolName = :symbolName 
            OR symbolItem.symbolName = :fullSymbolName)
          AND (symbolItem.debugId is NULL or symbolItem.debugId = :debugId)`, {
                symbolName: path.basename(symbolName, path.extname(symbolName)),
                fullSymbolName: symbolName,
                debugId,
            })
                .getQuery();
            return `(symbolServer.id NOT IN ${subQuery})`;
        })
            .andWhere((qb) => {
            const subQuery = qb
                .subQuery()
                .select('DISTINCT symbolItem.symbolServerId')
                .from(symbolItem_1.SymbolItem, 'symbolItem')
                .where(`
            symbolItem.type = 1 AND 
            (LOWER(symbolItem.symbolName) = LOWER(:symbolName) 
              OR symbolItem.symbolName = :fullSymbolName)`, {
                symbolName: path.basename(symbolName, path.extname(symbolName)),
                fullSymbolName: symbolName,
            })
                .getQuery();
            return `
          ((symbolServer.whiteList = 1 AND symbolServer.id IN ${subQuery}) 
          OR symbolServer.whiteList =0)`;
        })
            .groupBy('symbolserver.id')
            .orderBy('priority.priority', 'DESC')
            .addOrderBy('symbolServer.creationDate', 'DESC')
            .getMany();
    }
    async getByUniverseName(universeName, page = 0, take = 10) {
        this._logger.info('Fetching universe from coronerd');
        const universe = await this._universeService.fetchOrTryAdd(universeName);
        this._logger.info('Successfully fetched Universe. Creating query builder');
        if (!universe) {
            throw new common_1.BadRequestException(`Universe doesn't exists`);
        }
        const result = await this.getProjectQueryBuilder(universe.id)
            .skip(page * take)
            .take(take)
            .getManyAndCount();
        return result;
    }
    async getByProjectName(universeName, projectName, page = 0, take = 10) {
        const universe = await this._universeService.fetchOrTryAdd(universeName, projectName);
        if (!universe) {
            throw new common_1.BadRequestException(`Universe doesn't exist`);
        }
        const project = universe.project && universe.project.length !== 0 ? universe.project[0] : undefined;
        if (!project) {
            throw new common_1.BadRequestException(`Project ${projectName} doesn't exist`);
        }
        return await this.getProjectQueryBuilder(universe.id, project.id)
            .orderBy('symbolServer.creationDate', 'ASC')
            .skip(page * take)
            .take(take)
            .getManyAndCount();
    }
    async exists(symbolServerId) {
        const counter = await this._symbolServerRepository.count({
            where: {
                id: symbolServerId,
            },
        });
        return counter !== 0;
    }
    async toggle(symbolServerId, disable = false) {
        const symbolServer = await this._symbolServerRepository.findOne({ id: symbolServerId });
        if (!symbolServer) {
            throw new common_1.NotFoundException(`Symbol Server doesn't exists`);
        }
        symbolServer.disable = disable;
        await this._symbolServerRepository.save(symbolServer);
    }
    async validate(url, symbolServer, secretFile) {
        var _a, _b, _c, _d, _e;
        const checkInstanceType = (serverType) => serverType.id !== undefined;
        const id = checkInstanceType(symbolServer) ? symbolServer.id : undefined;
        const type = ((_a = symbolServer.serverCredentials) === null || _a === void 0 ? void 0 : _a.type) || credentialsType_1.CredentialsType.Default;
        switch (type) {
            case credentialsType_1.CredentialsType.Default:
                try {
                    const response = await axios_1.default.get(symbolServer.url + url, {
                        proxy: symbolServer.proxy === undefined
                            ? undefined
                            : {
                                host: symbolServer.proxy.host,
                                port: symbolServer.proxy.port,
                                auth: {
                                    password: symbolServer.proxy.password,
                                    username: symbolServer.proxy.username,
                                },
                            },
                        auth: symbolServer.serverCredentials === undefined
                            ? undefined
                            : {
                                username: symbolServer.serverCredentials.userName,
                                password: symbolServer.serverCredentials.password,
                            },
                    });
                    return {
                        id,
                        status: response.status === 200,
                    };
                }
                catch (err) {
                    return {
                        id,
                        status: false,
                        message: err.message,
                    };
                }
            case credentialsType_1.CredentialsType.AWS:
                try {
                    await new aws_sdk_1.S3({
                        endpoint: symbolServer.url,
                        accessKeyId: (_b = symbolServer === null || symbolServer === void 0 ? void 0 : symbolServer.serverCredentials) === null || _b === void 0 ? void 0 : _b.accessKeyId,
                        secretAccessKey: (_c = symbolServer === null || symbolServer === void 0 ? void 0 : symbolServer.serverCredentials) === null || _c === void 0 ? void 0 : _c.secretAccessKey,
                    })
                        .getObject({
                        Bucket: ((_d = symbolServer === null || symbolServer === void 0 ? void 0 : symbolServer.serverCredentials) === null || _d === void 0 ? void 0 : _d.bucketName) || '',
                        Key: url,
                    })
                        .promise();
                    return {
                        id,
                        status: true,
                    };
                }
                catch (err) {
                    return {
                        id,
                        status: false,
                        message: err.message,
                    };
                }
            case credentialsType_1.CredentialsType.GCP:
                const storage = new storage_1.Storage({
                    keyFilename: secretFile,
                });
                const bucket = storage.bucket(((_e = symbolServer === null || symbolServer === void 0 ? void 0 : symbolServer.serverCredentials) === null || _e === void 0 ? void 0 : _e.bucketName) || '');
                try {
                    await bucket.file(url).download();
                    return {
                        id,
                        status: true,
                    };
                }
                catch (err) {
                    return {
                        id,
                        status: false,
                        message: err.message,
                    };
                }
        }
    }
    async fetchStatuses(ids) {
        const symbolServers = await this._symbolServerRepository.findByIds(ids);
        const promises = [];
        for (const symbolServer of symbolServers) {
            if (symbolServer.hidden) {
                continue;
            }
            promises.push(this.validate('', symbolServer));
        }
        return Promise.all(promises);
    }
    async add(symbolServer) {
        const entity = this._symbolServerRepository.create(symbolServer);
        entity.statistics = {
            numberOfBytesDownloaded: 0,
        };
        return await this._symbolServerRepository.save(entity);
    }
    async update(id, model, force = false) {
        const entity = await this._symbolServerRepository.findOne(id, {
            join: {
                alias: 'symbolServer',
                leftJoinAndSelect: {
                    proxy: 'symbolServer.proxy',
                    serverCredentials: 'symbolServer.serverCredentials',
                },
            },
        });
        if (!entity) {
            throw new common_1.BadRequestException(`Entity with id ${id} doens't exists`);
        }
        if (!entity.universeId && !entity.projectId && force === false) {
            throw new common_1.BadRequestException(`Cannot update global symbol server. Please contact with Backtrace Administrator`);
        }
        if (model.ignoreCredentials !== true) {
            await this._proxyService.setupEntity(entity.id, model.proxy);
            await this._serverCredentialsService.setupEntity(entity.id, model.serverCredentials);
        }
        model.proxy = undefined;
        model.serverCredentials = undefined;
        const comparer = Object.assign({}, new symbolServer_1.SymbolServer(), model);
        const data = Object.assign({}, entity, comparer);
        await this._symbolServerRepository.save(data);
    }
    async getGlobalSymbolServers() {
        return await this._symbolServerRepository
            .createQueryBuilder('symbolServer')
            .leftJoinAndSelect('symbolServer.serverCredentials', 'serverCredentials')
            .where('symbolServer.projectId is NULL AND symbolServer.universeId is NULL')
            .getMany();
    }
    async getByUrl(url, bucketName) {
        return await this._symbolServerRepository.findOne({
            join: {
                alias: 'symbolServer',
                leftJoinAndSelect: {
                    serverCredentials: 'symbolServer.serverCredentials',
                },
            },
            where: {
                url,
                serverCredentials: {
                    bucketName,
                },
            },
        });
    }
    async getById(id) {
        return await this._symbolServerRepository.findOne({
            join: {
                alias: 'symbolServer',
                leftJoinAndSelect: {
                    proxy: 'symbolServer.proxy',
                    serverCredentials: 'symbolServer.serverCredentials',
                    statistics: 'symbolServer.statistics',
                    project: 'symbolServer.project',
                    universe: 'symbolServer.universe',
                    universeProject: 'project.universe',
                },
            },
            where: {
                id,
            },
        });
    }
    async get() {
        return await this._symbolServerRepository.find();
    }
    async remove(id, force = false) {
        var _a, _b;
        const entity = await this._symbolServerRepository.findOne(id, {
            join: {
                alias: 'symbolServer',
                leftJoinAndSelect: {
                    serverCredentials: 'symbolServer.serverCredentials',
                },
            },
        });
        if (!entity) {
            throw new common_1.BadRequestException(`Entity doesn't exists`);
        }
        if (force === false && !entity.universeId && !entity.projectId) {
            throw new common_1.BadRequestException(`Cannot remove global symbol server`);
        }
        await this._symbolServerRepository.manager.transaction(async (transactionManager) => {
            await transactionManager
                .createQueryBuilder()
                .delete()
                .from('SymbolServerStatistics')
                .where('symbolServerId= :id', { id })
                .execute();
            await transactionManager
                .createQueryBuilder()
                .delete()
                .from('SymbolServerLog')
                .where('symbolServerId= :id', { id })
                .execute();
            await transactionManager
                .createQueryBuilder()
                .delete()
                .from('SymbolItem')
                .where('symbolServerId= :id', { id })
                .execute();
            await transactionManager
                .createQueryBuilder()
                .delete()
                .from('SymbolServerPriority')
                .where('symbolServerId= :id', { id })
                .execute();
            await transactionManager
                .createQueryBuilder()
                .delete()
                .from('ServerCredentials')
                .where('symbolServerId= :id', { id })
                .execute();
            await transactionManager
                .createQueryBuilder()
                .delete()
                .from('SymbolServer')
                .where('id= :id', { id })
                .execute();
        });
        if ((_a = entity.serverCredentials) === null || _a === void 0 ? void 0 : _a.secretFile) {
            await fs_extra_1.remove((_b = entity.serverCredentials) === null || _b === void 0 ? void 0 : _b.secretFile);
        }
    }
    getProjectQueryBuilder(universeId, projectId, hidden = false) {
        return this._symbolServerRepository
            .createQueryBuilder('symbolServer')
            .leftJoinAndSelect('symbolServer.statistics', 'statistics')
            .leftJoinAndSelect('symbolServer.proxy', 'proxy')
            .leftJoinAndSelect('symbolServer.serverCredentials', 'serverCredentials')
            .leftJoinAndSelect('symbolServer.priorities', 'priority', !!projectId ? 'priority.projectId = :projectId' : 'priority.universeId = :projectId', {
            projectId: projectId || universeId,
        })
            .where(`(
          (symbolServer.projectId is NULL and symbolServer.universeId is NULL)
          OR ${!!projectId
            ? `(symbolServer.universeId = ${universeId} 
                AND symbolServer.projectId is NULL) 
                OR symbolServer.projectId = :projectId`
            : 'symbolServer.universeId = :projectId'}) and symbolServer.hidden = :hidden
          `, {
            projectId: projectId || universeId,
            hidden,
        })
            .orderBy('priority.priority', 'DESC')
            .addOrderBy('symbolServer.creationDate', 'DESC');
    }
};
SymbolServerService = __decorate([
    common_1.Injectable(),
    __param(0, typeorm_2.InjectRepository(symbolServer_1.SymbolServer)),
    __param(3, common_1.Inject(common_1.forwardRef(() => symbol_item_service_1.SymbolItemService))),
    __metadata("design:paramtypes", [typeorm_1.Repository,
        proxy_service_1.ProxyService,
        server_credentials_service_1.ServerCredentialsService,
        symbol_item_service_1.SymbolItemService,
        universe_service_1.UniverseService,
        logger_service_1.LoggerService])
], SymbolServerService);
exports.SymbolServerService = SymbolServerService;
//# sourceMappingURL=symbol-server.service.js.map