"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SymbolsController = void 0;
const common_1 = require("@nestjs/common");
const authGuard_1 = require("../../guards/authGuard");
const authHelper_1 = require("../../helpers/authHelper");
const config_service_1 = require("../config/config.service");
const logger_service_1 = require("../logger/logger.service");
const universe_service_1 = require("../universe/universe.service");
const symbols_service_1 = require("./symbols.service");
let SymbolsController = class SymbolsController {
    constructor(_configService, _universeService, _symbolService, _logger) {
        this._configService = _configService;
        this._universeService = _universeService;
        this._symbolService = _symbolService;
        this._logger = _logger;
    }
    getId({ coronerAuth }, res) {
        this._configService.identityManager.bypassProjectAccessCheck(res);
        if (!this._configService.api.fetchSecret) {
            return new common_1.BadRequestException(`Fetch secret is not defined. Please contact Backtrace support`);
        }
        if (!coronerAuth || !coronerAuth.cfg) {
            return new common_1.UnauthorizedException();
        }
        this._logger.info(`User ${coronerAuth.cfg.username} fetch symbols endpoint secret`);
        res.send({
            secret: this._configService.api.fetchSecret,
        });
    }
    async status(req, res, universeName, projectName, symbolName, debugId) {
        if (!this._configService.identityManager.checkProjectAccess(req, res, [projectName])) {
            return res.send();
        }
        if (!debugId || !symbolName) {
            throw new common_1.BadRequestException('Missing debugId or symbol name');
        }
        if (!req.coronerAuth || !authHelper_1.AuthHelper.checkUserAccess(req.coronerAuth, universeName)) {
            this._logger.warn(`User without access to universe tried to create symbol server.
         ${universeName} ${projectName} `);
            throw new common_1.UnauthorizedException();
        }
        const universe = await this._universeService.fetchOrTryAdd(universeName, projectName);
        if (!universe) {
            this._logger.warn(`Cannot fetch symbol status: universe doesn't exists`);
            throw new common_1.BadRequestException();
        }
        res.send(await this._symbolService.getSymbolsStatus(universeName, projectName, symbolName, debugId, req.coronerAuth.token));
    }
    async get(universeName, symbolName, debugId, hash, response) {
        this._configService.identityManager.bypassProjectAccessCheck(response);
        await this.validateSymbolsDownload(hash, universeName, symbolName, debugId);
        const data = await this._symbolService.getStream(symbolName, debugId, universeName);
        this.pipeResponse(data, symbolName, debugId, response);
    }
    async getByProjectName(req, res, universeName, projectName, symbolName, debugId, hash) {
        if (!this._configService.identityManager.checkProjectAccess(req, res, [projectName])) {
            return res.send();
        }
        await this.validateSymbolsDownload(hash, universeName, symbolName, debugId, projectName);
        const data = await this._symbolService.getStream(symbolName, debugId, universeName, projectName);
        this.pipeResponse(data, symbolName, debugId, res);
    }
    pipeResponse(data, symbolName, debugId, response) {
        if (data === undefined) {
            this._logger.info(`Cannot found any symbol for ${symbolName},${debugId}`);
            throw new common_1.NotFoundException();
        }
        this._logger.info(`Symbol is available - returning symbol ${symbolName},${debugId}`);
        response.setHeader('Content-Type', `application/octet-stream`);
        response.setHeader('Content-disposition', `attachment; filename=${symbolName}`);
        data.pipe(response);
    }
    async validateSymbolsDownload(hash, universeName, symbolName, debugId, projectName) {
        if (!hash || hash !== this._configService.api.fetchSecret) {
            this._logger.info(`Received a request with invalid secret hash`);
            throw new common_1.UnauthorizedException('Invalid hash parameter');
        }
        const universe = await this._universeService.fetchOrTryAdd(universeName, projectName);
        if (!universe) {
            throw new common_1.BadRequestException(`Universe doesn't exists`);
        }
        this._logger.info(`Fetch symbols: returning data for symbol ${symbolName},${debugId}`);
    }
};
__decorate([
    common_1.UseGuards(authGuard_1.AuthGuard),
    common_1.Get('id'),
    __param(0, common_1.Req()), __param(1, common_1.Res()),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, Object]),
    __metadata("design:returntype", void 0)
], SymbolsController.prototype, "getId", null);
__decorate([
    common_1.UseGuards(authGuard_1.AuthGuard),
    common_1.Get('status/:universeName/:projectName/:symbolName/:debugId'),
    __param(0, common_1.Req()),
    __param(1, common_1.Res()),
    __param(2, common_1.Param('universeName')),
    __param(3, common_1.Param('projectName')),
    __param(4, common_1.Param('symbolName')),
    __param(5, common_1.Param('debugId')),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, Object, String, String, String, String]),
    __metadata("design:returntype", Promise)
], SymbolsController.prototype, "status", null);
__decorate([
    common_1.Get(':universeName/:hash/:symbolName/:debugId/:symbolName'),
    __param(0, common_1.Param('universeName')),
    __param(1, common_1.Param('symbolName')),
    __param(2, common_1.Param('debugId')),
    __param(3, common_1.Param('hash')),
    __param(4, common_1.Res()),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, String, String, String, Object]),
    __metadata("design:returntype", Promise)
], SymbolsController.prototype, "get", null);
__decorate([
    common_1.Get(':universeName/:projectName/:hash/:symbolName/:debugId/:symbolName'),
    __param(0, common_1.Req()),
    __param(1, common_1.Res()),
    __param(2, common_1.Param('universeName')),
    __param(3, common_1.Param('projectName')),
    __param(4, common_1.Param('symbolName')),
    __param(5, common_1.Param('debugId')),
    __param(6, common_1.Param('hash')),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, Object, String, String, String, String, String]),
    __metadata("design:returntype", Promise)
], SymbolsController.prototype, "getByProjectName", null);
SymbolsController = __decorate([
    common_1.Controller('symbols'),
    __metadata("design:paramtypes", [config_service_1.ConfigService,
        universe_service_1.UniverseService,
        symbols_service_1.SymbolService,
        logger_service_1.LoggerService])
], SymbolsController);
exports.SymbolsController = SymbolsController;
//# sourceMappingURL=symbols.controller.js.map