"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UniverseService = void 0;
const typeorm_1 = require("typeorm");
const universe_1 = require("../../database/entities/universe");
const project_service_1 = require("./../project/project.service");
const common_1 = require("@nestjs/common");
const typeorm_2 = require("@nestjs/typeorm");
const config_service_1 = require("../config/config.service");
const logger_service_1 = require("../logger/logger.service");
const env_1 = require("../../env");
let UniverseService = class UniverseService {
    constructor(_universeRepository, _projectService, _configService, _logger) {
        this._universeRepository = _universeRepository;
        this._projectService = _projectService;
        this._configService = _configService;
        this._logger = _logger;
    }
    async getUniverseIdByUniverseName(name) {
        if (!name) {
            return undefined;
        }
        const universe = await this.getByUniverseName(name);
        return universe ? universe.id : undefined;
    }
    async getByUniverseName(name) {
        return await this.getUniverse({ name });
    }
    async getByUniverseId(id) {
        return await this.getUniverse({ id });
    }
    async addProjectIfUniverseExists(projectName, universeName) {
        const universe = await this.getByUniverseName(universeName);
        if (!universe) {
            return undefined;
        }
        return await this._projectService.tryAdd({
            universeId: universe.id,
            name: projectName,
        });
    }
    async fetchOrTryAdd(universeName, projectName) {
        if (!universeName || !env_1.coronerdUrl) {
            return undefined;
        }
        let universe = await this.getByUniverseName(universeName);
        if (universe && !projectName) {
            return universe;
        }
        if (universe && projectName) {
            const universeProj = await this._projectService.getByProjectName(projectName, universeName);
            if (universeProj) {
                universe.project = [universeProj];
                return universe;
            }
        }
        const serviceConfig = await this._configService.identityManager.loginCoronerd(env_1.coronerdUrl);
        if (!serviceConfig) {
            return undefined;
        }
        const serviceUniverse = serviceConfig.universes[universeName];
        if (!serviceUniverse) {
            return undefined;
        }
        if (!universe) {
            universe = await this.add({
                name: universeName,
            });
        }
        if (!projectName) {
            return universe;
        }
        const projectToAdd = serviceUniverse.projects.filter((n) => n === projectName);
        if (!projectToAdd || projectToAdd.length === 0) {
            return universe;
        }
        const project = await this._projectService.tryAdd({
            name: projectName,
            universeId: universe.id,
        });
        if (!project) {
            return universe;
        }
        if (!universe.project) {
            universe.project = [];
        }
        universe.project.push(project);
        return universe;
    }
    async add(universe) {
        if (!universe.name) {
            throw new Error('Universe name is required');
        }
        return await this._universeRepository.save(universe);
    }
    async startupUniverse(url) {
        this._logger.debug('Fetching Universes/Projects from coronerd ');
        const serviceConfig = await this._configService.identityManager.loginCoronerd(url);
        if (!serviceConfig) {
            this._logger.warn(`Cannot receive any information from coronerd.` +
                `Are you sure symbold have correct coronerd address?`);
            return;
        }
        for (const universeKey in serviceConfig.universes) {
            const universe = serviceConfig.universes[universeKey];
            if (!universe) {
                this._logger.warn(`Response universe is empty - cannot fetch universe/project from coronerd`);
                return;
            }
            const exists = await this.getByUniverseName(universeKey);
            if (exists) {
                this._logger.debug(`Universe ${universeKey} already exists in database. Skipping adding new Unvierse`);
                continue;
            }
            this._logger.debug(`Trying to add default universe "${universeKey}" and all universe projects`);
            await this.add({
                name: universeKey,
            });
            const projects = universe.projects;
            for (const project of projects) {
                const result = await this.fetchOrTryAdd(universeKey, project);
                if (result) {
                    this._logger.log('Successfully added new project to universe');
                }
                else {
                    this._logger.warn(`Cannot add universe and + project. Informations: ${JSON.stringify(result)}`);
                }
            }
        }
    }
    async getUniverse(universeFilter) {
        const findConditions = {
            where: universeFilter,
        };
        return await this._universeRepository.findOne(findConditions);
    }
};
UniverseService = __decorate([
    common_1.Injectable(),
    __param(0, typeorm_2.InjectRepository(universe_1.Universe)),
    __metadata("design:paramtypes", [typeorm_1.Repository,
        project_service_1.ProjectService,
        config_service_1.ConfigService,
        logger_service_1.LoggerService])
], UniverseService);
exports.UniverseService = UniverseService;
//# sourceMappingURL=universe.service.js.map