"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.WhiteListController = void 0;
const authGuard_1 = require("./../../guards/authGuard");
const common_1 = require("@nestjs/common");
const symbol_item_service_1 = require("../symbol-item/symbol-item.service");
const symbolItemType_1 = require("../../database/entities/types/symbolItemType");
const parseOptionalInt_1 = require("../../pipes/parseOptionalInt");
const logger_service_1 = require("../logger/logger.service");
const config_service_1 = require("../config/config.service");
let WhiteListController = class WhiteListController {
    constructor(_logger, _symbolItemService, _configService) {
        this._logger = _logger;
        this._symbolItemService = _symbolItemService;
        this._configService = _configService;
        this._symbolItemType = symbolItemType_1.SymbolItemType.WhiteList;
    }
    async get(req, res, symbolServerId, page, take) {
        if (!req.coronerAuth || !req.coronerAuth.cfg) {
            this._configService.identityManager.bypassProjectAccessCheck(res);
            return res.send();
        }
        this._logger.info(`User ${req.coronerAuth.cfg.username} fetch symbol server ${symbolServerId} whitelist`);
        const results = await this._symbolItemService.getBySymbolServerIdWithProjectValidation(this._configService, req, res, symbolServerId, this._symbolItemType, page, take);
        res.send(results);
    }
    async delete(req, res, whiteSymbolId) {
        if (!req.coronerAuth || !req.coronerAuth.cfg) {
            this._configService.identityManager.bypassProjectAccessCheck(res);
            return res.send();
        }
        this._logger.info(`User ${req.coronerAuth.cfg.username} trying to remove whitelist item ${whiteSymbolId}`);
        await this._symbolItemService.removeWithProjectValidation(this._configService, req, res, whiteSymbolId, this._symbolItemType);
        res.send({
            statusCode: 200,
            message: 'deleted',
            err: undefined,
        });
    }
    async add(req, res, symbolServerId, data) {
        if (!req.coronerAuth || !req.coronerAuth.cfg) {
            this._configService.identityManager.bypassProjectAccessCheck(res);
            return res.send();
        }
        this._logger.info(`User ${req.coronerAuth.cfg.username} trying to add whitelist to symbol server ${symbolServerId}`);
        await this._symbolItemService.addCollectionWithProjectValidation(this._configService, req, res, data.model, symbolServerId, this._symbolItemType);
        res.send({
            statusCode: 200,
            message: 'created',
            err: undefined,
        });
    }
};
__decorate([
    common_1.Get(':symbolServerId'),
    __param(0, common_1.Req()),
    __param(1, common_1.Res()),
    __param(2, common_1.Param('symbolServerId', new common_1.ParseIntPipe())),
    __param(3, common_1.Query('page', new parseOptionalInt_1.ParseOptionalIntPipe())),
    __param(4, common_1.Query('take', new parseOptionalInt_1.ParseOptionalIntPipe())),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, Object, Number, Object, Object]),
    __metadata("design:returntype", Promise)
], WhiteListController.prototype, "get", null);
__decorate([
    common_1.Delete(':whiteSymbolId'),
    __param(0, common_1.Req()),
    __param(1, common_1.Res()),
    __param(2, common_1.Param('whiteSymbolId', new common_1.ParseIntPipe())),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, Object, Number]),
    __metadata("design:returntype", Promise)
], WhiteListController.prototype, "delete", null);
__decorate([
    common_1.Post(':symbolServerId'),
    __param(0, common_1.Req()),
    __param(1, common_1.Res()),
    __param(2, common_1.Param('symbolServerId', new common_1.ParseIntPipe())),
    __param(3, common_1.Body(new common_1.ValidationPipe({ transform: true }))),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, Object, Number, Object]),
    __metadata("design:returntype", Promise)
], WhiteListController.prototype, "add", null);
WhiteListController = __decorate([
    common_1.Controller('whiteList'),
    common_1.UseGuards(authGuard_1.AuthGuard),
    __metadata("design:paramtypes", [logger_service_1.LoggerService,
        symbol_item_service_1.SymbolItemService,
        config_service_1.ConfigService])
], WhiteListController);
exports.WhiteListController = WhiteListController;
//# sourceMappingURL=white-list.controller.js.map