"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SymbolServer = void 0;
const typeorm_1 = require("typeorm");
const url_1 = __importDefault(require("url"));
const project_1 = require("./project");
const proxy_1 = require("./proxy");
const serverCredentials_1 = require("./serverCredentials");
const symbolItem_1 = require("./symbolItem");
const symbolServerLog_1 = require("./symbolServerLog");
const universe_1 = require("./universe");
const symbolServerStatistics_1 = require("./symbolServerStatistics");
const symbolServerPriority_1 = require("./symbolServerPriority");
let SymbolServer = class SymbolServer {
    constructor() {
        this.numberOfConcurrentDownload = 5;
        this.retryLimit = 3;
        this.disable = false;
        this.retryTimeout = 1000;
        this.timeout = 10000;
        this.whiteList = false;
        this.hidden = false;
    }
    loadPriorities() {
        this.priority =
            (this.priorities && this.priorities[0] && this.priorities[0].priority) ||
                this.creationDate.getTime();
    }
    updateSymbolServerName() {
        if (!this.name) {
            const obj = url_1.default.parse(this.url);
            this.name = obj.hostname;
        }
    }
    get isGlobalSymbolServer() {
        return this.projectId === null && this.universeId === null;
    }
};
__decorate([
    typeorm_1.PrimaryGeneratedColumn({ type: 'int' }),
    __metadata("design:type", Number)
], SymbolServer.prototype, "id", void 0);
__decorate([
    typeorm_1.Column(),
    __metadata("design:type", String)
], SymbolServer.prototype, "url", void 0);
__decorate([
    typeorm_1.Column(),
    __metadata("design:type", String)
], SymbolServer.prototype, "name", void 0);
__decorate([
    typeorm_1.Column({ default: 5 }),
    __metadata("design:type", Number)
], SymbolServer.prototype, "numberOfConcurrentDownload", void 0);
__decorate([
    typeorm_1.Column({ default: 1 }),
    __metadata("design:type", Number)
], SymbolServer.prototype, "retryLimit", void 0);
__decorate([
    typeorm_1.Column({ default: false }),
    __metadata("design:type", Boolean)
], SymbolServer.prototype, "disable", void 0);
__decorate([
    typeorm_1.Column({ default: 1000 }),
    __metadata("design:type", Number)
], SymbolServer.prototype, "retryTimeout", void 0);
__decorate([
    typeorm_1.Column({ default: 10000 }),
    __metadata("design:type", Number)
], SymbolServer.prototype, "timeout", void 0);
__decorate([
    typeorm_1.Column({ default: false }),
    __metadata("design:type", Boolean)
], SymbolServer.prototype, "whiteList", void 0);
__decorate([
    typeorm_1.Column({ default: null }),
    __metadata("design:type", String)
], SymbolServer.prototype, "queryBuilder", void 0);
__decorate([
    typeorm_1.Column({ default: false }),
    __metadata("design:type", Boolean)
], SymbolServer.prototype, "hidden", void 0);
__decorate([
    typeorm_1.CreateDateColumn(),
    __metadata("design:type", Date)
], SymbolServer.prototype, "creationDate", void 0);
__decorate([
    typeorm_1.UpdateDateColumn(),
    __metadata("design:type", Date)
], SymbolServer.prototype, "lastUpdateDate", void 0);
__decorate([
    typeorm_1.Column({ type: 'int', nullable: true }),
    __metadata("design:type", Object)
], SymbolServer.prototype, "projectId", void 0);
__decorate([
    typeorm_1.ManyToOne((type) => project_1.Project, (project) => project.symbolServer),
    typeorm_1.JoinColumn(),
    __metadata("design:type", project_1.Project)
], SymbolServer.prototype, "project", void 0);
__decorate([
    typeorm_1.Column({ type: 'int', nullable: true }),
    __metadata("design:type", Object)
], SymbolServer.prototype, "universeId", void 0);
__decorate([
    typeorm_1.ManyToOne((type) => universe_1.Universe, (universe) => universe.symbolServer),
    typeorm_1.JoinColumn({ name: 'universeId' }),
    __metadata("design:type", universe_1.Universe)
], SymbolServer.prototype, "universe", void 0);
__decorate([
    typeorm_1.OneToOne((type) => serverCredentials_1.ServerCredentials, (serverCredentials) => serverCredentials.symbolServer, {
        cascade: true,
        nullable: true,
        onDelete: 'CASCADE',
    }),
    __metadata("design:type", serverCredentials_1.ServerCredentials)
], SymbolServer.prototype, "serverCredentials", void 0);
__decorate([
    typeorm_1.OneToOne((type) => proxy_1.Proxy, (proxy) => proxy.symbolServer, {
        cascade: true,
        nullable: true,
        onDelete: 'CASCADE',
    }),
    __metadata("design:type", proxy_1.Proxy)
], SymbolServer.prototype, "proxy", void 0);
__decorate([
    typeorm_1.OneToOne((type) => symbolServerStatistics_1.SymbolServerStatistics, (statistics) => statistics.symbolServer, {
        cascade: true,
        onDelete: 'CASCADE',
    }),
    __metadata("design:type", symbolServerStatistics_1.SymbolServerStatistics)
], SymbolServer.prototype, "statistics", void 0);
__decorate([
    typeorm_1.OneToMany((type) => symbolItem_1.SymbolItem, (symbolItem) => symbolItem.symbolServer, {
        cascade: true,
        onDelete: 'CASCADE',
    }),
    __metadata("design:type", Array)
], SymbolServer.prototype, "symbolItem", void 0);
__decorate([
    typeorm_1.OneToMany((type) => symbolServerLog_1.SymbolServerLog, (log) => log.symbolServer, {
        cascade: true,
        onDelete: 'CASCADE',
    }),
    __metadata("design:type", Array)
], SymbolServer.prototype, "logs", void 0);
__decorate([
    typeorm_1.OneToMany((type) => symbolServerPriority_1.SymbolServerPriority, (symbolServerPriority) => symbolServerPriority.symbolServer, {
        cascade: true,
        onDelete: 'CASCADE',
    }),
    __metadata("design:type", Array)
], SymbolServer.prototype, "priorities", void 0);
__decorate([
    typeorm_1.AfterLoad(),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], SymbolServer.prototype, "loadPriorities", null);
__decorate([
    typeorm_1.BeforeInsert(),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], SymbolServer.prototype, "updateSymbolServerName", null);
SymbolServer = __decorate([
    typeorm_1.Entity()
], SymbolServer);
exports.SymbolServer = SymbolServer;
//# sourceMappingURL=symbolServer.js.map