"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InitialMigration1565551789859 = void 0;
class InitialMigration1565551789859 {
    async up(queryRunner) {
        let databaseExists = true;
        try {
            await queryRunner.query('SELECT * FROM SYMBOL_SERVER');
            databaseExists = true;
        }
        catch (err) {
            databaseExists = false;
        }
        if (databaseExists) {
            return;
        }
        await queryRunner.query(`CREATE TABLE "symbol_server_priority" ("id" integer PRIMARY KEY AUTOINCREMENT NOT NULL, "priority" integer NOT NULL, "symbolServerId" integer NOT NULL, "projectId" integer, "universeId" integer)`);
        await queryRunner.query(`CREATE TABLE "universe" ("id" integer PRIMARY KEY AUTOINCREMENT NOT NULL, "name" varchar NOT NULL)`);
        await queryRunner.query(`CREATE TABLE "project" ("id" integer PRIMARY KEY AUTOINCREMENT NOT NULL, "name" varchar NOT NULL, "universeId" integer NOT NULL)`);
        await queryRunner.query(`CREATE TABLE "proxy" ("id" integer PRIMARY KEY AUTOINCREMENT NOT NULL, "host" varchar NOT NULL, "port" integer NOT NULL, "username" varchar NOT NULL, "password" varchar NOT NULL, "symbolServerId" integer NOT NULL, CONSTRAINT "REL_db2947a904481d0e004ff39367" UNIQUE ("symbolServerId"))`);
        await queryRunner.query(`CREATE TABLE "symbol_item" ("id" integer PRIMARY KEY AUTOINCREMENT NOT NULL, "symbolName" varchar NOT NULL, "debugId" varchar, "creationDate" datetime NOT NULL DEFAULT (datetime('now')), "type" integer NOT NULL, "symbolServerId" integer NOT NULL)`);
        await queryRunner.query(`CREATE INDEX "IDX_a02aa247f4240ccf85a052e4b7" ON "symbol_item" ("symbolName", "type") `);
        await queryRunner.query(`CREATE TABLE "symbol_server_log" ("id" integer PRIMARY KEY AUTOINCREMENT NOT NULL, "creationDate" datetime NOT NULL DEFAULT (datetime('now')), "type" integer NOT NULL, "message" text NOT NULL, "symbolServerId" integer NOT NULL)`);
        await queryRunner.query(`CREATE TABLE "symbol_server_statistics" ("id" integer PRIMARY KEY AUTOINCREMENT NOT NULL, "numberOfBytesDownloaded" bigint NOT NULL DEFAULT (0), "numberOfFailuresAtDownloadStage" integer NOT NULL DEFAULT (0), "numberOfSuccessAtDownloadStage" integer NOT NULL DEFAULT (0), "numberOfSuccessAtSymbolConversionStage" integer NOT NULL DEFAULT (0), "numberOfFailuresAtSymbolConversionStage" integer NOT NULL DEFAULT (0), "symbolServerId" integer NOT NULL, CONSTRAINT "REL_40711d18d440a726cc3e1b9993" UNIQUE ("symbolServerId"))`);
        await queryRunner.query(`CREATE TABLE "symbol_server" ("id" integer PRIMARY KEY AUTOINCREMENT NOT NULL, "url" varchar NOT NULL, "name" varchar NOT NULL, "numberOfConcurrentDownload" integer NOT NULL DEFAULT (5), "retryLimit" integer NOT NULL DEFAULT (3), "disable" boolean NOT NULL DEFAULT (0), "retryTimeout" integer NOT NULL DEFAULT (3000), "timeout" integer NOT NULL DEFAULT (10000), "whiteList" boolean NOT NULL DEFAULT (0), "creationDate" datetime NOT NULL DEFAULT (datetime('now')), "lastUpdateDate" datetime NOT NULL DEFAULT (datetime('now')), "projectId" integer, "universeId" integer)`);
        await queryRunner.query(`CREATE TABLE "server_credentials" ("id" integer PRIMARY KEY AUTOINCREMENT NOT NULL, "userName" varchar NOT NULL, "password" varchar NOT NULL, "symbolServerId" integer NOT NULL, CONSTRAINT "REL_025e77be0b6547cef174942383" UNIQUE ("symbolServerId"))`);
        await queryRunner.query(`CREATE TABLE "aws_connection" ("id" integer PRIMARY KEY AUTOINCREMENT NOT NULL, "bucketName" varchar NOT NULL, "lowerFile" boolean NOT NULL, "lowerId" boolean NOT NULL, "usePdb" boolean NOT NULL, "serverCredentialsId" integer NOT NULL, CONSTRAINT "REL_ee56dbc449c6e48e8de146baed" UNIQUE ("serverCredentialsId"))`);
        await queryRunner.query(`CREATE TABLE "temporary_symbol_server_priority" ("id" integer PRIMARY KEY AUTOINCREMENT NOT NULL, "priority" integer NOT NULL, "symbolServerId" integer NOT NULL, "projectId" integer, "universeId" integer, CONSTRAINT "FK_febcb096478244b4d3acd39ea79" FOREIGN KEY ("symbolServerId") REFERENCES "symbol_server" ("id") ON DELETE NO ACTION ON UPDATE NO ACTION, CONSTRAINT "FK_0441407abf194bfb4def2932e8c" FOREIGN KEY ("projectId") REFERENCES "project" ("id") ON DELETE NO ACTION ON UPDATE NO ACTION, CONSTRAINT "FK_cd90d386a0beb2d300742becd15" FOREIGN KEY ("universeId") REFERENCES "universe" ("id") ON DELETE NO ACTION ON UPDATE NO ACTION)`);
        await queryRunner.query(`INSERT INTO "temporary_symbol_server_priority"("id", "priority", "symbolServerId", "projectId", "universeId") SELECT "id", "priority", "symbolServerId", "projectId", "universeId" FROM "symbol_server_priority"`);
        await queryRunner.query(`DROP TABLE "symbol_server_priority"`);
        await queryRunner.query(`ALTER TABLE "temporary_symbol_server_priority" RENAME TO "symbol_server_priority"`);
        await queryRunner.query(`CREATE TABLE "temporary_project" ("id" integer PRIMARY KEY AUTOINCREMENT NOT NULL, "name" varchar NOT NULL, "universeId" integer NOT NULL, CONSTRAINT "FK_6132181f438f3eb608d12143752" FOREIGN KEY ("universeId") REFERENCES "universe" ("id") ON DELETE CASCADE ON UPDATE NO ACTION)`);
        await queryRunner.query(`INSERT INTO "temporary_project"("id", "name", "universeId") SELECT "id", "name", "universeId" FROM "project"`);
        await queryRunner.query(`DROP TABLE "project"`);
        await queryRunner.query(`ALTER TABLE "temporary_project" RENAME TO "project"`);
        await queryRunner.query(`CREATE TABLE "temporary_proxy" ("id" integer PRIMARY KEY AUTOINCREMENT NOT NULL, "host" varchar NOT NULL, "port" integer NOT NULL, "username" varchar NOT NULL, "password" varchar NOT NULL, "symbolServerId" integer NOT NULL, CONSTRAINT "REL_db2947a904481d0e004ff39367" UNIQUE ("symbolServerId"), CONSTRAINT "FK_db2947a904481d0e004ff393676" FOREIGN KEY ("symbolServerId") REFERENCES "symbol_server" ("id") ON DELETE CASCADE ON UPDATE NO ACTION)`);
        await queryRunner.query(`INSERT INTO "temporary_proxy"("id", "host", "port", "username", "password", "symbolServerId") SELECT "id", "host", "port", "username", "password", "symbolServerId" FROM "proxy"`);
        await queryRunner.query(`DROP TABLE "proxy"`);
        await queryRunner.query(`ALTER TABLE "temporary_proxy" RENAME TO "proxy"`);
        await queryRunner.query(`DROP INDEX "IDX_a02aa247f4240ccf85a052e4b7"`);
        await queryRunner.query(`CREATE TABLE "temporary_symbol_item" ("id" integer PRIMARY KEY AUTOINCREMENT NOT NULL, "symbolName" varchar NOT NULL, "debugId" varchar, "creationDate" datetime NOT NULL DEFAULT (datetime('now')), "type" integer NOT NULL, "symbolServerId" integer NOT NULL, CONSTRAINT "FK_64e3ed6a81c0d95e4d27852c061" FOREIGN KEY ("symbolServerId") REFERENCES "symbol_server" ("id") ON DELETE NO ACTION ON UPDATE NO ACTION)`);
        await queryRunner.query(`INSERT INTO "temporary_symbol_item"("id", "symbolName", "debugId", "creationDate", "type", "symbolServerId") SELECT "id", "symbolName", "debugId", "creationDate", "type", "symbolServerId" FROM "symbol_item"`);
        await queryRunner.query(`DROP TABLE "symbol_item"`);
        await queryRunner.query(`ALTER TABLE "temporary_symbol_item" RENAME TO "symbol_item"`);
        await queryRunner.query(`CREATE INDEX "IDX_a02aa247f4240ccf85a052e4b7" ON "symbol_item" ("symbolName", "type") `);
        await queryRunner.query(`CREATE TABLE "temporary_symbol_server_log" ("id" integer PRIMARY KEY AUTOINCREMENT NOT NULL, "creationDate" datetime NOT NULL DEFAULT (datetime('now')), "type" integer NOT NULL, "message" text NOT NULL, "symbolServerId" integer NOT NULL, CONSTRAINT "FK_fb02acafa53b7565a5c04dc7bea" FOREIGN KEY ("symbolServerId") REFERENCES "symbol_server" ("id") ON DELETE CASCADE ON UPDATE NO ACTION)`);
        await queryRunner.query(`INSERT INTO "temporary_symbol_server_log"("id", "creationDate", "type", "message", "symbolServerId") SELECT "id", "creationDate", "type", "message", "symbolServerId" FROM "symbol_server_log"`);
        await queryRunner.query(`DROP TABLE "symbol_server_log"`);
        await queryRunner.query(`ALTER TABLE "temporary_symbol_server_log" RENAME TO "symbol_server_log"`);
        await queryRunner.query(`CREATE TABLE "temporary_symbol_server_statistics" ("id" integer PRIMARY KEY AUTOINCREMENT NOT NULL, "numberOfBytesDownloaded" bigint NOT NULL DEFAULT (0), "numberOfFailuresAtDownloadStage" integer NOT NULL DEFAULT (0), "numberOfSuccessAtDownloadStage" integer NOT NULL DEFAULT (0), "numberOfSuccessAtSymbolConversionStage" integer NOT NULL DEFAULT (0), "numberOfFailuresAtSymbolConversionStage" integer NOT NULL DEFAULT (0), "symbolServerId" integer NOT NULL, CONSTRAINT "REL_40711d18d440a726cc3e1b9993" UNIQUE ("symbolServerId"), CONSTRAINT "FK_40711d18d440a726cc3e1b9993a" FOREIGN KEY ("symbolServerId") REFERENCES "symbol_server" ("id") ON DELETE CASCADE ON UPDATE NO ACTION)`);
        await queryRunner.query(`INSERT INTO "temporary_symbol_server_statistics"("id", "numberOfBytesDownloaded", "numberOfFailuresAtDownloadStage", "numberOfSuccessAtDownloadStage", "numberOfSuccessAtSymbolConversionStage", "numberOfFailuresAtSymbolConversionStage", "symbolServerId") SELECT "id", "numberOfBytesDownloaded", "numberOfFailuresAtDownloadStage", "numberOfSuccessAtDownloadStage", "numberOfSuccessAtSymbolConversionStage", "numberOfFailuresAtSymbolConversionStage", "symbolServerId" FROM "symbol_server_statistics"`);
        await queryRunner.query(`DROP TABLE "symbol_server_statistics"`);
        await queryRunner.query(`ALTER TABLE "temporary_symbol_server_statistics" RENAME TO "symbol_server_statistics"`);
        await queryRunner.query(`CREATE TABLE "temporary_symbol_server" ("id" integer PRIMARY KEY AUTOINCREMENT NOT NULL, "url" varchar NOT NULL, "name" varchar NOT NULL, "numberOfConcurrentDownload" integer NOT NULL DEFAULT (5), "retryLimit" integer NOT NULL DEFAULT (3), "disable" boolean NOT NULL DEFAULT (0), "retryTimeout" integer NOT NULL DEFAULT (3000), "timeout" integer NOT NULL DEFAULT (10000), "whiteList" boolean NOT NULL DEFAULT (0), "creationDate" datetime NOT NULL DEFAULT (datetime('now')), "lastUpdateDate" datetime NOT NULL DEFAULT (datetime('now')), "projectId" integer, "universeId" integer, CONSTRAINT "FK_141b9b47631302e0b8e00fd742b" FOREIGN KEY ("projectId") REFERENCES "project" ("id") ON DELETE NO ACTION ON UPDATE NO ACTION, CONSTRAINT "FK_ab3bd06d51756e543297d54efd4" FOREIGN KEY ("universeId") REFERENCES "universe" ("id") ON DELETE NO ACTION ON UPDATE NO ACTION)`);
        await queryRunner.query(`INSERT INTO "temporary_symbol_server"("id", "url", "name", "numberOfConcurrentDownload", "retryLimit", "disable", "retryTimeout", "timeout", "whiteList", "creationDate", "lastUpdateDate", "projectId", "universeId") SELECT "id", "url", "name", "numberOfConcurrentDownload", "retryLimit", "disable", "retryTimeout", "timeout", "whiteList", "creationDate", "lastUpdateDate", "projectId", "universeId" FROM "symbol_server"`);
        await queryRunner.query(`DROP TABLE "symbol_server"`);
        await queryRunner.query(`ALTER TABLE "temporary_symbol_server" RENAME TO "symbol_server"`);
        await queryRunner.query(`CREATE TABLE "temporary_server_credentials" ("id" integer PRIMARY KEY AUTOINCREMENT NOT NULL, "userName" varchar NOT NULL, "password" varchar NOT NULL, "symbolServerId" integer NOT NULL, CONSTRAINT "REL_025e77be0b6547cef174942383" UNIQUE ("symbolServerId"), CONSTRAINT "FK_025e77be0b6547cef1749423830" FOREIGN KEY ("symbolServerId") REFERENCES "symbol_server" ("id") ON DELETE CASCADE ON UPDATE NO ACTION)`);
        await queryRunner.query(`INSERT INTO "temporary_server_credentials"("id", "userName", "password", "symbolServerId") SELECT "id", "userName", "password", "symbolServerId" FROM "server_credentials"`);
        await queryRunner.query(`DROP TABLE "server_credentials"`);
        await queryRunner.query(`ALTER TABLE "temporary_server_credentials" RENAME TO "server_credentials"`);
        await queryRunner.query(`CREATE TABLE "temporary_aws_connection" ("id" integer PRIMARY KEY AUTOINCREMENT NOT NULL, "bucketName" varchar NOT NULL, "lowerFile" boolean NOT NULL, "lowerId" boolean NOT NULL, "usePdb" boolean NOT NULL, "serverCredentialsId" integer NOT NULL, CONSTRAINT "REL_ee56dbc449c6e48e8de146baed" UNIQUE ("serverCredentialsId"), CONSTRAINT "FK_ee56dbc449c6e48e8de146baeda" FOREIGN KEY ("serverCredentialsId") REFERENCES "server_credentials" ("id") ON DELETE CASCADE ON UPDATE NO ACTION)`);
        await queryRunner.query(`INSERT INTO "temporary_aws_connection"("id", "bucketName", "lowerFile", "lowerId", "usePdb", "serverCredentialsId") SELECT "id", "bucketName", "lowerFile", "lowerId", "usePdb", "serverCredentialsId" FROM "aws_connection"`);
        await queryRunner.query(`DROP TABLE "aws_connection"`);
        await queryRunner.query(`ALTER TABLE "temporary_aws_connection" RENAME TO "aws_connection"`);
    }
    async down(queryRunner) {
        await queryRunner.query(`ALTER TABLE "aws_connection" RENAME TO "temporary_aws_connection"`);
        await queryRunner.query(`CREATE TABLE "aws_connection" ("id" integer PRIMARY KEY AUTOINCREMENT NOT NULL, "bucketName" varchar NOT NULL, "lowerFile" boolean NOT NULL, "lowerId" boolean NOT NULL, "usePdb" boolean NOT NULL, "serverCredentialsId" integer NOT NULL, CONSTRAINT "REL_ee56dbc449c6e48e8de146baed" UNIQUE ("serverCredentialsId"))`);
        await queryRunner.query(`INSERT INTO "aws_connection"("id", "bucketName", "lowerFile", "lowerId", "usePdb", "serverCredentialsId") SELECT "id", "bucketName", "lowerFile", "lowerId", "usePdb", "serverCredentialsId" FROM "temporary_aws_connection"`);
        await queryRunner.query(`DROP TABLE "temporary_aws_connection"`);
        await queryRunner.query(`ALTER TABLE "server_credentials" RENAME TO "temporary_server_credentials"`);
        await queryRunner.query(`CREATE TABLE "server_credentials" ("id" integer PRIMARY KEY AUTOINCREMENT NOT NULL, "userName" varchar NOT NULL, "password" varchar NOT NULL, "symbolServerId" integer NOT NULL, CONSTRAINT "REL_025e77be0b6547cef174942383" UNIQUE ("symbolServerId"))`);
        await queryRunner.query(`INSERT INTO "server_credentials"("id", "userName", "password", "symbolServerId") SELECT "id", "userName", "password", "symbolServerId" FROM "temporary_server_credentials"`);
        await queryRunner.query(`DROP TABLE "temporary_server_credentials"`);
        await queryRunner.query(`ALTER TABLE "symbol_server" RENAME TO "temporary_symbol_server"`);
        await queryRunner.query(`CREATE TABLE "symbol_server" ("id" integer PRIMARY KEY AUTOINCREMENT NOT NULL, "url" varchar NOT NULL, "name" varchar NOT NULL, "numberOfConcurrentDownload" integer NOT NULL DEFAULT (5), "retryLimit" integer NOT NULL DEFAULT (3), "disable" boolean NOT NULL DEFAULT (0), "retryTimeout" integer NOT NULL DEFAULT (3000), "timeout" integer NOT NULL DEFAULT (10000), "whiteList" boolean NOT NULL DEFAULT (0), "creationDate" datetime NOT NULL DEFAULT (datetime('now')), "lastUpdateDate" datetime NOT NULL DEFAULT (datetime('now')), "projectId" integer, "universeId" integer)`);
        await queryRunner.query(`INSERT INTO "symbol_server"("id", "url", "name", "numberOfConcurrentDownload", "retryLimit", "disable", "retryTimeout", "timeout", "whiteList", "creationDate", "lastUpdateDate", "projectId", "universeId") SELECT "id", "url", "name", "numberOfConcurrentDownload", "retryLimit", "disable", "retryTimeout", "timeout", "whiteList", "creationDate", "lastUpdateDate", "projectId", "universeId" FROM "temporary_symbol_server"`);
        await queryRunner.query(`DROP TABLE "temporary_symbol_server"`);
        await queryRunner.query(`ALTER TABLE "symbol_server_statistics" RENAME TO "temporary_symbol_server_statistics"`);
        await queryRunner.query(`CREATE TABLE "symbol_server_statistics" ("id" integer PRIMARY KEY AUTOINCREMENT NOT NULL, "numberOfBytesDownloaded" bigint NOT NULL DEFAULT (0), "numberOfFailuresAtDownloadStage" integer NOT NULL DEFAULT (0), "numberOfSuccessAtDownloadStage" integer NOT NULL DEFAULT (0), "numberOfSuccessAtSymbolConversionStage" integer NOT NULL DEFAULT (0), "numberOfFailuresAtSymbolConversionStage" integer NOT NULL DEFAULT (0), "symbolServerId" integer NOT NULL, CONSTRAINT "REL_40711d18d440a726cc3e1b9993" UNIQUE ("symbolServerId"))`);
        await queryRunner.query(`INSERT INTO "symbol_server_statistics"("id", "numberOfBytesDownloaded", "numberOfFailuresAtDownloadStage", "numberOfSuccessAtDownloadStage", "numberOfSuccessAtSymbolConversionStage", "numberOfFailuresAtSymbolConversionStage", "symbolServerId") SELECT "id", "numberOfBytesDownloaded", "numberOfFailuresAtDownloadStage", "numberOfSuccessAtDownloadStage", "numberOfSuccessAtSymbolConversionStage", "numberOfFailuresAtSymbolConversionStage", "symbolServerId" FROM "temporary_symbol_server_statistics"`);
        await queryRunner.query(`DROP TABLE "temporary_symbol_server_statistics"`);
        await queryRunner.query(`ALTER TABLE "symbol_server_log" RENAME TO "temporary_symbol_server_log"`);
        await queryRunner.query(`CREATE TABLE "symbol_server_log" ("id" integer PRIMARY KEY AUTOINCREMENT NOT NULL, "creationDate" datetime NOT NULL DEFAULT (datetime('now')), "type" integer NOT NULL, "message" text NOT NULL, "symbolServerId" integer NOT NULL)`);
        await queryRunner.query(`INSERT INTO "symbol_server_log"("id", "creationDate", "type", "message", "symbolServerId") SELECT "id", "creationDate", "type", "message", "symbolServerId" FROM "temporary_symbol_server_log"`);
        await queryRunner.query(`DROP TABLE "temporary_symbol_server_log"`);
        await queryRunner.query(`DROP INDEX "IDX_a02aa247f4240ccf85a052e4b7"`);
        await queryRunner.query(`ALTER TABLE "symbol_item" RENAME TO "temporary_symbol_item"`);
        await queryRunner.query(`CREATE TABLE "symbol_item" ("id" integer PRIMARY KEY AUTOINCREMENT NOT NULL, "symbolName" varchar NOT NULL, "debugId" varchar, "creationDate" datetime NOT NULL DEFAULT (datetime('now')), "type" integer NOT NULL, "symbolServerId" integer NOT NULL)`);
        await queryRunner.query(`INSERT INTO "symbol_item"("id", "symbolName", "debugId", "creationDate", "type", "symbolServerId") SELECT "id", "symbolName", "debugId", "creationDate", "type", "symbolServerId" FROM "temporary_symbol_item"`);
        await queryRunner.query(`DROP TABLE "temporary_symbol_item"`);
        await queryRunner.query(`CREATE INDEX "IDX_a02aa247f4240ccf85a052e4b7" ON "symbol_item" ("symbolName", "type") `);
        await queryRunner.query(`ALTER TABLE "proxy" RENAME TO "temporary_proxy"`);
        await queryRunner.query(`CREATE TABLE "proxy" ("id" integer PRIMARY KEY AUTOINCREMENT NOT NULL, "host" varchar NOT NULL, "port" integer NOT NULL, "username" varchar NOT NULL, "password" varchar NOT NULL, "symbolServerId" integer NOT NULL, CONSTRAINT "REL_db2947a904481d0e004ff39367" UNIQUE ("symbolServerId"))`);
        await queryRunner.query(`INSERT INTO "proxy"("id", "host", "port", "username", "password", "symbolServerId") SELECT "id", "host", "port", "username", "password", "symbolServerId" FROM "temporary_proxy"`);
        await queryRunner.query(`DROP TABLE "temporary_proxy"`);
        await queryRunner.query(`ALTER TABLE "project" RENAME TO "temporary_project"`);
        await queryRunner.query(`CREATE TABLE "project" ("id" integer PRIMARY KEY AUTOINCREMENT NOT NULL, "name" varchar NOT NULL, "universeId" integer NOT NULL)`);
        await queryRunner.query(`INSERT INTO "project"("id", "name", "universeId") SELECT "id", "name", "universeId" FROM "temporary_project"`);
        await queryRunner.query(`DROP TABLE "temporary_project"`);
        await queryRunner.query(`ALTER TABLE "symbol_server_priority" RENAME TO "temporary_symbol_server_priority"`);
        await queryRunner.query(`CREATE TABLE "symbol_server_priority" ("id" integer PRIMARY KEY AUTOINCREMENT NOT NULL, "priority" integer NOT NULL, "symbolServerId" integer NOT NULL, "projectId" integer, "universeId" integer)`);
        await queryRunner.query(`INSERT INTO "symbol_server_priority"("id", "priority", "symbolServerId", "projectId", "universeId") SELECT "id", "priority", "symbolServerId", "projectId", "universeId" FROM "temporary_symbol_server_priority"`);
        await queryRunner.query(`DROP TABLE "temporary_symbol_server_priority"`);
        await queryRunner.query(`DROP TABLE "aws_connection"`);
        await queryRunner.query(`DROP TABLE "server_credentials"`);
        await queryRunner.query(`DROP TABLE "symbol_server"`);
        await queryRunner.query(`DROP TABLE "symbol_server_statistics"`);
        await queryRunner.query(`DROP TABLE "symbol_server_log"`);
        await queryRunner.query(`DROP INDEX "IDX_a02aa247f4240ccf85a052e4b7"`);
        await queryRunner.query(`DROP TABLE "symbol_item"`);
        await queryRunner.query(`DROP TABLE "proxy"`);
        await queryRunner.query(`DROP TABLE "project"`);
        await queryRunner.query(`DROP TABLE "universe"`);
        await queryRunner.query(`DROP TABLE "symbol_server_priority"`);
    }
}
exports.InitialMigration1565551789859 = InitialMigration1565551789859;
//# sourceMappingURL=1565551789859-InitialMigration.js.map