"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BufferHelper = void 0;
const symbolType_1 = require("../app/binary/model/symbolType");
const fs_1 = __importDefault(require("fs"));
class BufferHelper {
    static comapreString(buffer, comparerString) {
        const comparer = Buffer.from(comparerString);
        if (buffer.length < comparer.length) {
            return false;
        }
        return buffer.compare(comparer, 0, comparerString.length, 0, comparerString.length) === 0;
    }
    static getSymbolFromPath(symbolPath) {
        return new Promise((res, rej) => {
            const stream = fs_1.default.createReadStream(symbolPath, { start: 0, end: 100 });
            stream.on('data', (buffer) => {
                return res(this.getSymbolTypeFromBuffer(buffer));
            });
            stream.on('error', (err) => {
                return res(symbolType_1.SymbolType.Unknown);
            });
            stream.resume();
        });
    }
    static getSymbolTypeFromBuffer(buffer) {
        if (BufferHelper.comapreString(buffer, 'Microsoft C/C++ MSF 7.00')) {
            return symbolType_1.SymbolType.Pdb;
        }
        else if (BufferHelper.comapreString(buffer, 'MSCF')) {
            return symbolType_1.SymbolType.Cabinet;
        }
        else if (BufferHelper.comapreString(buffer, 'MZ')) {
            return symbolType_1.SymbolType.Pe;
        }
        else if (BufferHelper.comapreString(buffer, 'MODULE')) {
            return symbolType_1.SymbolType.Sym;
        }
        else if (BufferHelper.comapreString(buffer, 'ELF')) {
            return symbolType_1.SymbolType.Elf;
        }
        else {
            return symbolType_1.SymbolType.Unknown;
        }
    }
}
exports.BufferHelper = BufferHelper;
//# sourceMappingURL=bufferHelper.js.map