"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.nestLoader = void 0;
const common_1 = require("@nestjs/common");
const nest_factory_1 = require("@nestjs/core/nest-factory");
const app_module_1 = require("../app.module");
const logger_service_1 = require("../app/logger/logger.service");
const errorMiddleware_1 = require("../app/middlewares/errorMiddleware");
const env_1 = require("../env");
const platform_express_1 = require("@nestjs/platform-express");
async function nestLoader() {
    var _a, _b, _c;
    const apiFactory = new nest_factory_1.NestFactoryStatic();
    const logger = new logger_service_1.LoggerService();
    const api = await apiFactory.create(app_module_1.ApplicationModule, new platform_express_1.ExpressAdapter(env_1.service.app), {
        cors: true,
        logger,
        httpsOptions: env_1.readSslCerts(),
    });
    api.setGlobalPrefix(((_a = env_1.service.configuration.descriptor) === null || _a === void 0 ? void 0 : _a.resource) || '/api/symbold');
    const errorMiddleware = api.get(errorMiddleware_1.ErrorMiddleware);
    api.useGlobalFilters(errorMiddleware);
    api.useGlobalPipes(new common_1.ValidationPipe({
        transform: true,
        disableErrorMessages: false,
        whitelist: true,
        skipMissingProperties: true,
    }));
    api.enableShutdownHooks();
    await api.init();
    logger.info(`Application is starting on port: ${(_b = env_1.service.configuration.descriptor) === null || _b === void 0 ? void 0 : _b.port}`);
    await api.listen(((_c = env_1.service.configuration.descriptor) === null || _c === void 0 ? void 0 : _c.port) || env_1.port);
}
exports.nestLoader = nestLoader;
//# sourceMappingURL=nestLoader.js.map