"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const bad_request_exception_1 = require("../exceptions/bad-request.exception");
const index_1 = require("../index");
/**
 * Defines the built-in ParseInt Pipe
 *
 * @see [Built-in Pipes](https://docs.nestjs.com/pipes#built-in-pipes)
 *
 * @publicApi
 */
let ParseIntPipe = class ParseIntPipe {
    constructor(options) {
        options = options || {};
        const { exceptionFactory } = options;
        this.exceptionFactory =
            exceptionFactory || (error => new bad_request_exception_1.BadRequestException(error));
    }
    /**
     * Method that accesses and performs optional transformation on argument for
     * in-flight requests.
     *
     * @param value currently processed route argument
     * @param metadata contains metadata about the currently processed route argument
     */
    async transform(value, metadata) {
        const isNumeric = ['string', 'number'].includes(typeof value) &&
            !isNaN(parseFloat(value)) &&
            isFinite(value);
        if (!isNumeric) {
            throw this.exceptionFactory('Validation failed (numeric string is expected)');
        }
        return parseInt(value, 10);
    }
};
ParseIntPipe = tslib_1.__decorate([
    index_1.Injectable(),
    tslib_1.__param(0, index_1.Optional()),
    tslib_1.__metadata("design:paramtypes", [Object])
], ParseIntPipe);
exports.ParseIntPipe = ParseIntPipe;
