"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDescriptor = exports.getCoronerConfig = exports.listenDescriptor = void 0;
var crypto_1 = require("crypto");
var fs = __importStar(require("fs"));
var http = __importStar(require("http"));
var https = __importStar(require("https"));
var mkdirp_1 = __importDefault(require("mkdirp"));
var os_1 = __importDefault(require("os"));
var path_1 = __importDefault(require("path"));
var cluster_1 = __importDefault(require("cluster"));
var url = __importStar(require("url"));
var logger_1 = require("./../log/logger");
// XXX: better default?
var defaultCoronerdHostname = '0.0.0.0';
var logger = logger_1.Logger.getLogger();
function readJSONFile(filePath) {
    var obj = null;
    try {
        obj = JSON.parse(fs.readFileSync(filePath, { encoding: 'utf8' }));
    }
    catch (e) {
        return undefined;
    }
    return obj;
}
function getCoronerdHostname(crcfg) {
    var alldescPath = process.env.ALL_DESCRIPTOR_PATH || crcfg.varprefix + "/_all.json";
    // if coronerd has supplied its REST URL, then use it.
    if (!fs.existsSync(alldescPath)) {
        return defaultCoronerdHostname;
    }
    var alldesc = readJSONFile(alldescPath);
    if (alldesc && typeof alldesc.coronerd === 'string') {
        var crUrl = url.parse(alldesc.coronerd);
        if (crUrl.hostname) {
            return crUrl.hostname;
        }
    }
    return defaultCoronerdHostname;
}
function listenDescriptor(descr, app, credentials, callback, clusterSupport) {
    if (clusterSupport === void 0) { clusterSupport = false; }
    // Set up server
    var server;
    switch (descr.protocol) {
        case 'http':
            server = http.createServer(app);
            break;
        case 'https':
            if (!credentials) {
                throw new Error("Empty credentials.");
            }
            server = https.createServer(credentials, app);
            break;
        default:
            throw new Error("unknown protocol " + descr.protocol);
    }
    if (clusterSupport) {
        // Set up master/workers
        if (cluster_1.default.isMaster) {
            var numWorkers = Number.isInteger(clusterSupport)
                ? clusterSupport
                : os_1.default.cpus().length;
            logger.info("Master cluster setting up " + numWorkers + " workers...");
            for (var i = 0; i < numWorkers; i++) {
                cluster_1.default.fork();
            }
            cluster_1.default.on('online', function workerOnline(worker) {
                logger.info("Worker " + worker.process.pid + " is online.");
            });
            cluster_1.default.on('exit', function workerExit(worker, code, signal) {
                logger.info("Worker " + worker.process.pid + " died with code: " + code + ",\n          and signal: " + signal + ". Starting a new worker");
                cluster_1.default.fork();
            });
        }
        else {
            server.listen(descr.port, function startListening() {
                logger.info("Process " + process.pid + " is listening to all incoming requests.");
                if (callback) {
                    callback();
                }
            });
        }
    }
    else {
        server.listen(descr.port, callback);
    }
}
exports.listenDescriptor = listenDescriptor;
function getCoronerConfig() {
    var cfg = {
        svcDescriptorPrefix: process.env.SERVICE_DESCRIPTOR_VARPREFIX,
        svclayerPrefix: process.env.SERVICE_LAYER_VARPREFIX,
        filePath: process.env.CORONERD_CONF || '/etc/coronerd/coronerd.conf',
        varprefix: undefined,
        json: undefined,
    };
    cfg.json = readJSONFile(cfg.filePath);
    if (cfg.json) {
        if (cfg.json.svclayer) {
            var descriptionExists = Array.isArray(cfg.json.svclayer.descriptorpaths) &&
                cfg.json.svclayer.descriptorpaths.length > 0;
            if (descriptionExists) {
                /*
                 * Prefer the last element as it will customarily be one that the
                 * service can write new files to.
                 */
                var paths = cfg.json.svclayer.descriptorpaths;
                cfg.svcDescriptorPrefix = paths[paths.length - 1];
            }
            if (!cfg.svclayerPrefix && cfg.json.svclayer.varpath) {
                cfg.svclayerPrefix = cfg.json.svclayer.varpath;
            }
        }
        cfg.varprefix = cfg.json.varprefix;
    }
    /* Implement hardcoded fallbacks that match coronerd's. */
    if (!cfg.varprefix) {
        cfg.varprefix = '/var/run/coronerd';
    }
    if (!cfg.svclayerPrefix) {
        cfg.svclayerPrefix = cfg.varprefix + "/svclayer";
    }
    if (!cfg.svcDescriptorPrefix) {
        cfg.svcDescriptorPrefix = cfg.varprefix + "/services.d";
    }
    return cfg;
}
exports.getCoronerConfig = getCoronerConfig;
/**
 * getDescriptor fetches the service's integration parameters.
 * @param serviceName - service name - for example: share/saml/comments
 * @param defaultPort - the default port number for the service.
 * @param opts - descriptor options
 */
function getDescriptor(serviceName, defaultPort, opts) {
    if (opts === void 0) { opts = {}; }
    var crcfg = getCoronerConfig();
    var varPath = process.env.SERVICE_DESCRIPTOR_VARPATH ||
        crcfg.svcDescriptorPrefix + "/" + serviceName + ".json";
    var paths = getDescriptorPaths(serviceName, varPath);
    var foundPath = '';
    var desc;
    for (var _i = 0, paths_1 = paths; _i < paths_1.length; _i++) {
        var descriptorPath = paths_1[_i];
        desc = readDescriptorConfiguration(descriptorPath);
        if (desc) {
            foundPath = descriptorPath;
            break;
        }
    }
    // if descriptor doesn't exist in the descriptor search path,
    // generate new descriptor file with default configuration in the
    // var path, where it can own the file.
    if (!desc) {
        desc = getDefaultDescriptor(serviceName, defaultPort, crcfg, opts);
        mkdirp_1.default(path_1.default.dirname(varPath), function (err) {
            if (err) {
                throw err;
            }
            fs.writeFileSync(varPath, JSON.stringify(desc, null, 2));
        });
    }
    var surl = new url.URL(desc.server);
    // if the descriptor owned by the service was read in and happens to
    // contain the invalid-for-SSL default hostname "0.0.0.0" that was
    // written out previously, see whether it can be automatically fixed up.
    if (foundPath === varPath && surl.hostname === defaultCoronerdHostname) {
        var hostname = getCoronerdHostname(crcfg);
        if (hostname !== defaultCoronerdHostname) {
            surl.hostname = hostname;
            desc.server = surl.toString();
            fs.writeFileSync(varPath, JSON.stringify(desc, null, 2));
        }
    }
    var port = surl.protocol === 'https:' ? 443 : 80;
    if (surl.port) {
        port = parseInt(surl.port, 10);
    }
    return {
        name: desc.name,
        port: port,
        resource: desc.resource,
        secret: desc.secret,
        isOnPremise: desc.proxy,
        protocol: surl.protocol.split(':')[0],
    };
}
exports.getDescriptor = getDescriptor;
function getDefaultDescriptor(serviceName, defaultPort, crcfg, opts) {
    var protocol = opts.protocol ? opts.protocol : 'http';
    var hostname = getCoronerdHostname(crcfg);
    return {
        name: serviceName,
        server: opts.server || protocol + "://" + hostname + ":" + defaultPort,
        secret: crypto_1.randomBytes(32).toString('hex'),
        resource: opts.resource || "/api/" + serviceName,
        proxy: opts.proxy !== undefined ? opts.proxy : true,
        enabled: true,
    };
}
function readDescriptorConfiguration(descriptorPath) {
    return readJSONFile(descriptorPath);
}
function getDescriptorPaths(serviceName, varPath) {
    return !process.env.SERVICE_DESCRIPTOR_PATH
        ? ["/etc/coronerd/services.d/" + serviceName + ".json", varPath]
        : [process.env.SERVICE_DESCRIPTOR_PATH];
}
//# sourceMappingURL=config.js.map