"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.projectValidation = exports.check = exports.setInvalid = exports.setValid = void 0;
function setValid(res) {
    res.projectValidated = true;
}
exports.setValid = setValid;
function setInvalid(res) {
    res.projectValidated = false;
}
exports.setInvalid = setInvalid;
/**
 * Checks if scopedProjects are in allKnownProjects and
 *      sets projectValidated flag on response object
 */
function check(res, allKnownProjects, scopedProjects) {
    // No scopedProjects is a cop-out.
    // Service owners can use original send method.
    if (!scopedProjects || scopedProjects.length === 0) {
        setInvalid(res);
        return false;
    }
    // Remove duplicates because size matters in the end
    var projects = Array.from(new Set(scopedProjects));
    var projectIdKey = 'pid';
    if (typeof projects[0] === 'string') {
        projectIdKey = 'name';
    }
    // Loop over known projects and record ones that matched scoped list.
    var seen = [];
    allKnownProjects.forEach(function (projectExt) {
        if (projects.includes(projectExt[projectIdKey])) {
            seen.push(projectExt[projectIdKey]);
        }
    });
    // Validate if seen list matches scoped list.
    // A bigger scoped list means invalid request.
    if (seen.length === projects.length) {
        setValid(res);
        return true;
    }
    setInvalid(res);
    return false;
}
exports.check = check;
/**
 *  Middleware for Backtrace Teams
 *    Alters the Express res.send function to return 403
 *    if projectValidation flag not set.
 */
function projectValidation(req, res, next) {
    var originalSend = res.send;
    // Altered res.send checks for projectValidated flag before continuing
    res.send = function (body) {
        if (res.projectValidated) {
            return originalSend.call(res, body);
        }
        res.statusCode = 403;
        return originalSend.call(res, 'project validation failed');
    };
    next();
}
exports.projectValidation = projectValidation;
//# sourceMappingURL=projectValidation.js.map